/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "ultron.tradingday.Schedule",
        "sources": [
            "ultron/tradingday/Schedule.pyx"
        ]
    },
    "module_name": "ultron.tradingday.Schedule"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__ultron__tradingday__Schedule
#define __PYX_HAVE_API__ultron__tradingday__Schedule
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "ultron/tradingday/Schedule.pyx",
  "ultron/tradingday/Schedule.pxd",
  "ultron/tradingday/Date.pxd",
  "ultron/tradingday/Period.pxd",
  "ultron/tradingday/Calendar.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_6ultron_10tradingday_4Date_Date;
struct __pyx_obj_6ultron_10tradingday_6Period_Period;
struct __pyx_obj_6ultron_10tradingday_8Calendar_CalendarImpl;
struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar;
struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule;
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_bizDaysBetween;
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_adjustDate;
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_advanceDate;
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_holDatesList;

/* "ultron/tradingday/Calendar.pxd":23
 *     cpdef isEndOfMonth(self, Date d)
 *     cpdef endOfMonth(self, Date d)
 *     cpdef bizDaysBetween(self, Date fromDate, Date toDate, bint includeFirst=*, bint includeLast=*)             # <<<<<<<<<<<<<<
 *     cpdef adjustDate(self, Date d, int c=*)
 *     cpdef advanceDate(self, Date d, Period period, int c=*, bint endOfMonth=*)
 */
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_bizDaysBetween {
  int __pyx_n;
  int includeFirst;
  int includeLast;
};

/* "ultron/tradingday/Calendar.pxd":24
 *     cpdef endOfMonth(self, Date d)
 *     cpdef bizDaysBetween(self, Date fromDate, Date toDate, bint includeFirst=*, bint includeLast=*)
 *     cpdef adjustDate(self, Date d, int c=*)             # <<<<<<<<<<<<<<
 *     cpdef advanceDate(self, Date d, Period period, int c=*, bint endOfMonth=*)
 *     cpdef holDatesList(self, Date fromDate, Date toDate, bint includeWeekEnds=*)
 */
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_adjustDate {
  int __pyx_n;
  int c;
};

/* "ultron/tradingday/Calendar.pxd":25
 *     cpdef bizDaysBetween(self, Date fromDate, Date toDate, bint includeFirst=*, bint includeLast=*)
 *     cpdef adjustDate(self, Date d, int c=*)
 *     cpdef advanceDate(self, Date d, Period period, int c=*, bint endOfMonth=*)             # <<<<<<<<<<<<<<
 *     cpdef holDatesList(self, Date fromDate, Date toDate, bint includeWeekEnds=*)
 *     cpdef bizDatesList(self, Date fromDate, Date toDate)
 */
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_advanceDate {
  int __pyx_n;
  int c;
  int endOfMonth;
};

/* "ultron/tradingday/Calendar.pxd":26
 *     cpdef adjustDate(self, Date d, int c=*)
 *     cpdef advanceDate(self, Date d, Period period, int c=*, bint endOfMonth=*)
 *     cpdef holDatesList(self, Date fromDate, Date toDate, bint includeWeekEnds=*)             # <<<<<<<<<<<<<<
 *     cpdef bizDatesList(self, Date fromDate, Date toDate)
 */
struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_holDatesList {
  int __pyx_n;
  int includeWeekEnds;
};

/* "ultron/tradingday/Enums/_BizDayConventions.pxd":3
 * # -*- coding: utf-8 -*-
 * 
 * cdef public enum BizDayConventions:             # <<<<<<<<<<<<<<
 *     Following = 0
 *     ModifiedFollowing = 1
 */
enum BizDayConventions {
  Following = 0,
  ModifiedFollowing = 1,
  Preceding = 2,
  ModifiedPreceding = 3,
  Unadjusted = 4,
  HalfMonthModifiedFollowing = 5,
  Nearest = 6
};

/* "ultron/tradingday/Enums/_DateGeneration.pxd":3
 * # -*- coding: utf-8 -*-
 * 
 * cdef public enum DateGeneration:             # <<<<<<<<<<<<<<
 *     Zero = 0
 *     Backward = 1
 */
enum DateGeneration {
  Zero = 0,
  Backward = 1,
  Forward = 2
};

/* "ultron/tradingday/Enums/_TimeUnits.pxd":3
 * # -*- coding: utf-8 -*-
 * 
 * cdef public enum TimeUnits:             # <<<<<<<<<<<<<<
 *     BDays = 0
 *     Days = 1
 */
enum TimeUnits {
  BDays = 0,
  Days = 1,
  Weeks = 2,
  Months = 3,
  Years = 4
};

/* "ultron/tradingday/Date.pxd":3
 * # -*- coding: utf-8 -*-
 * 
 * cdef class Date(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef public int __serialNumber__
 */
struct __pyx_obj_6ultron_10tradingday_4Date_Date {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ultron_10tradingday_4Date_Date *__pyx_vtab;
  int __serialNumber__;
  int _year;
  int _month;
  int _day;
};


/* "ultron/tradingday/Period.pxd":3
 * # -*- coding: utf-8 -*-
 * 
 * cdef class Period(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef public int _length
 */
struct __pyx_obj_6ultron_10tradingday_6Period_Period {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *__pyx_vtab;
  int _length;
  int _units;
};


/* "ultron/tradingday/Calendar.pxd":7
 * 
 * 
 * cdef class CalendarImpl(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef bint isBizDay(self, Date date)
 */
struct __pyx_obj_6ultron_10tradingday_8Calendar_CalendarImpl {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_CalendarImpl *__pyx_vtab;
};


/* "ultron/tradingday/Calendar.pxd":13
 * 
 * 
 * cdef class Calendar(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef public CalendarImpl _impl
 */
struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *__pyx_vtab;
  struct __pyx_obj_6ultron_10tradingday_8Calendar_CalendarImpl *_impl;
  PyObject *name;
};


/* "ultron/tradingday/Schedule.pxd":8
 * 
 * 
 * cdef class Schedule(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef public _effectiveDate
 */
struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule {
  PyObject_HEAD
  struct __pyx_vtabstruct_6ultron_10tradingday_8Schedule_Schedule *__pyx_vtab;
  PyObject *_effectiveDate;
  PyObject *_terminationDate;
  struct __pyx_obj_6ultron_10tradingday_6Period_Period *_tenor;
  struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *_cal;
  int _convention;
  int _terminationConvention;
  int _rule;
  PyObject *_dates;
  PyObject *_isRegular;
  int _endOfMonth;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *_firstDate;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *_nextToLastDate;
};



/* "ultron/tradingday/Date.pxd":3
 * # -*- coding: utf-8 -*-
 * 
 * cdef class Date(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef public int __serialNumber__
 */

struct __pyx_vtabstruct_6ultron_10tradingday_4Date_Date {
  int (*dayOfMonth)(struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  int (*dayOfYear)(struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  int (*year)(struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  int (*month)(struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  int (*weekday)(struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  PyObject *(*toDateTime)(struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  PyObject *(*_calculate_date)(struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int, int, int);
};
static struct __pyx_vtabstruct_6ultron_10tradingday_4Date_Date *__pyx_vtabptr_6ultron_10tradingday_4Date_Date;


/* "ultron/tradingday/Period.pxd":3
 * # -*- coding: utf-8 -*-
 * 
 * cdef class Period(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef public int _length
 */

struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period {
  struct __pyx_obj_6ultron_10tradingday_6Period_Period *(*normalize)(struct __pyx_obj_6ultron_10tradingday_6Period_Period *, int __pyx_skip_dispatch);
  int (*length)(struct __pyx_obj_6ultron_10tradingday_6Period_Period *, int __pyx_skip_dispatch);
  int (*units)(struct __pyx_obj_6ultron_10tradingday_6Period_Period *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *__pyx_vtabptr_6ultron_10tradingday_6Period_Period;


/* "ultron/tradingday/Calendar.pxd":7
 * 
 * 
 * cdef class CalendarImpl(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef bint isBizDay(self, Date date)
 */

struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_CalendarImpl {
  int (*isBizDay)(struct __pyx_obj_6ultron_10tradingday_8Calendar_CalendarImpl *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *);
  int (*isWeekEnd)(struct __pyx_obj_6ultron_10tradingday_8Calendar_CalendarImpl *, int);
};
static struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_CalendarImpl *__pyx_vtabptr_6ultron_10tradingday_8Calendar_CalendarImpl;


/* "ultron/tradingday/Calendar.pxd":13
 * 
 * 
 * cdef class Calendar(object):             # <<<<<<<<<<<<<<
 * 
 *     cdef public CalendarImpl _impl
 */

struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar {
  PyObject *(*isBizDay)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  PyObject *(*isHoliday)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  PyObject *(*isWeekEnd)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, int, int __pyx_skip_dispatch);
  PyObject *(*isEndOfMonth)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  PyObject *(*endOfMonth)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
  PyObject *(*bizDaysBetween)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch, struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_bizDaysBetween *__pyx_optional_args);
  PyObject *(*adjustDate)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch, struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_adjustDate *__pyx_optional_args);
  PyObject *(*advanceDate)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, struct __pyx_obj_6ultron_10tradingday_6Period_Period *, int __pyx_skip_dispatch, struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_advanceDate *__pyx_optional_args);
  PyObject *(*holDatesList)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch, struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_holDatesList *__pyx_optional_args);
  PyObject *(*bizDatesList)(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, struct __pyx_obj_6ultron_10tradingday_4Date_Date *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *__pyx_vtabptr_6ultron_10tradingday_8Calendar_Calendar;


/* "ultron/tradingday/Schedule.pyx":11
 * from ultron.tradingday.Env import Settings
 * 
 * cdef class Schedule(object):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self,
 */

struct __pyx_vtabstruct_6ultron_10tradingday_8Schedule_Schedule {
  size_t (*size)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch);
  int (*isRegular)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, size_t, int __pyx_skip_dispatch);
  struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *(*calendar)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch);
  struct __pyx_obj_6ultron_10tradingday_6Period_Period *(*tenor)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch);
  int (*endOfMonth)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6ultron_10tradingday_8Schedule_Schedule *__pyx_vtabptr_6ultron_10tradingday_8Schedule_Schedule;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__TimeUnits(enum TimeUnits value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static size_t __pyx_f_6ultron_10tradingday_8Schedule_8Schedule_size(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_calendar(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_6ultron_10tradingday_6Period_Period *__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_tenor(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6ultron_10tradingday_8Schedule_8Schedule_endOfMonth(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_6ultron_10tradingday_8Schedule_8Schedule_isRegular(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, size_t __pyx_v_i, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'ultron.tradingday.Date' */
static PyTypeObject *__pyx_ptype_6ultron_10tradingday_4Date_Date = 0;

/* Module declarations from 'ultron.tradingday.Period' */
static PyTypeObject *__pyx_ptype_6ultron_10tradingday_6Period_Period = 0;

/* Module declarations from 'ultron.tradingday.Calendar' */
static PyTypeObject *__pyx_ptype_6ultron_10tradingday_8Calendar_CalendarImpl = 0;
static PyTypeObject *__pyx_ptype_6ultron_10tradingday_8Calendar_Calendar = 0;

/* Module declarations from 'ultron.tradingday.Enums._BizDayConventions' */

/* Module declarations from 'ultron.tradingday.Enums._DateGeneration' */

/* Module declarations from 'ultron.tradingday.Enums._TimeUnits' */

/* Module declarations from 'ultron.tradingday.Schedule' */
static PyTypeObject *__pyx_ptype_6ultron_10tradingday_8Schedule_Schedule = 0;
#define __Pyx_MODULE_NAME "ultron.tradingday.Schedule"
extern int __pyx_module_is_main_ultron__tradingday__Schedule;
int __pyx_module_is_main_ultron__tradingday__Schedule = 0;

/* Implementation of 'ultron.tradingday.Schedule' */
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_range;
static const char __pyx_k_1M[] = "1M";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_Null[] = "Null";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_tenor[] = "tenor";
static const char __pyx_k_units[] = "units";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_length[] = "length";
static const char __pyx_k_Schedule[] = "Schedule";
static const char __pyx_k_Settings[] = "Settings";
static const char __pyx_k_calendar[] = "calendar";
static const char __pyx_k_firstDate[] = "firstDate";
static const char __pyx_k_isRegular[] = "isRegular";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_convention[] = "convention";
static const char __pyx_k_endOfMonth[] = "endOfMonth";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_effectiveDate[] = "effectiveDate";
static const char __pyx_k_evaluationDate[] = "evaluationDate";
static const char __pyx_k_nextToLastDate[] = "nextToLastDate";
static const char __pyx_k_terminationDate[] = "terminationDate";
static const char __pyx_k_unknown_rule_0_d[] = "unknown rule ({0:d})";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_dateGenerationRule[] = "dateGenerationRule";
static const char __pyx_k_terminationConvention[] = "terminationConvention";
static const char __pyx_k_ultron_tradingday_Env[] = "ultron.tradingday.Env";
static const char __pyx_k_first_date_incompatible_with_0_d[] = "first date incompatible with {0:d} date generation rule";
static const char __pyx_k_next_to_last_date_incompatible_w[] = "next to last date incompatible with {0:d} date generation rule";
static PyObject *__pyx_kp_s_1M;
static PyObject *__pyx_n_s_Null;
static PyObject *__pyx_n_s_Schedule;
static PyObject *__pyx_n_s_Settings;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s_calendar;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_convention;
static PyObject *__pyx_n_s_dateGenerationRule;
static PyObject *__pyx_n_s_effectiveDate;
static PyObject *__pyx_n_s_endOfMonth;
static PyObject *__pyx_n_s_evaluationDate;
static PyObject *__pyx_n_s_firstDate;
static PyObject *__pyx_kp_s_first_date_incompatible_with_0_d;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_isRegular;
static PyObject *__pyx_n_s_length;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_nextToLastDate;
static PyObject *__pyx_kp_s_next_to_last_date_incompatible_w;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_size;
static PyObject *__pyx_n_s_tenor;
static PyObject *__pyx_n_s_terminationConvention;
static PyObject *__pyx_n_s_terminationDate;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_ultron_tradingday_Env;
static PyObject *__pyx_n_s_units;
static PyObject *__pyx_kp_s_unknown_rule_0_d;
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule___init__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_effectiveDate, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_terminationDate, struct __pyx_obj_6ultron_10tradingday_6Period_Period *__pyx_v_tenor, struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *__pyx_v_calendar, int __pyx_v_convention, int __pyx_v_terminationConvention, int __pyx_v_dateGenerationRule, int __pyx_v_endOfMonth, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_firstDate, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_nextToLastDate); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_2size(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4calendar(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6tenor(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_8endOfMonth(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10isRegular(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, size_t __pyx_v_i); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_12__getitem__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14__deepcopy__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_memo); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16__reduce__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_18__setstate__(CYTHON_UNUSED struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_20__richcmp__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_other, int __pyx_v_op); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_convention___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_convention_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_5_rule___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_5_rule_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self); /* proto */
static PyObject *__pyx_tp_new_6ultron_10tradingday_8Schedule_Schedule(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop = {0, &__pyx_n_s_pop, 0, 0, 0};
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_366;
static int __pyx_k_;
static int __pyx_k__2;
static int __pyx_k__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
/* Late includes */

/* "ultron/tradingday/Schedule.pyx":13
 * cdef class Schedule(object):
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  Date effectiveDate,
 *                  Date terminationDate,
 */

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_effectiveDate = 0;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_terminationDate = 0;
  struct __pyx_obj_6ultron_10tradingday_6Period_Period *__pyx_v_tenor = 0;
  struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *__pyx_v_calendar = 0;
  int __pyx_v_convention;
  int __pyx_v_terminationConvention;
  int __pyx_v_dateGenerationRule;
  int __pyx_v_endOfMonth;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_firstDate = 0;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_nextToLastDate = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_effectiveDate,&__pyx_n_s_terminationDate,&__pyx_n_s_tenor,&__pyx_n_s_calendar,&__pyx_n_s_convention,&__pyx_n_s_terminationConvention,&__pyx_n_s_dateGenerationRule,&__pyx_n_s_endOfMonth,&__pyx_n_s_firstDate,&__pyx_n_s_nextToLastDate,0};
    PyObject* values[10] = {0,0,0,0,0,0,0,0,0,0};

    /* "ultron/tradingday/Schedule.pyx":22
 *                  int dateGenerationRule=DateGeneration.Forward,
 *                  bint endOfMonth=False,
 *                  Date firstDate=None,             # <<<<<<<<<<<<<<
 *                  Date nextToLastDate=None):
 * 
 */
    values[8] = (PyObject *)((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None);

    /* "ultron/tradingday/Schedule.pyx":23
 *                  bint endOfMonth=False,
 *                  Date firstDate=None,
 *                  Date nextToLastDate=None):             # <<<<<<<<<<<<<<
 * 
 *         cdef int i
 */
    values[9] = (PyObject *)((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_effectiveDate)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_terminationDate)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 10, 1); __PYX_ERR(0, 13, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tenor)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 10, 2); __PYX_ERR(0, 13, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_calendar)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 10, 3); __PYX_ERR(0, 13, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_convention);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_terminationConvention);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dateGenerationRule);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_endOfMonth);
          if (value) { values[7] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_firstDate);
          if (value) { values[8] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_nextToLastDate);
          if (value) { values[9] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 13, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_effectiveDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)values[0]);
    __pyx_v_terminationDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)values[1]);
    __pyx_v_tenor = ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)values[2]);
    __pyx_v_calendar = ((struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *)values[3]);
    if (values[4]) {
      __pyx_v_convention = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_convention == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 18, __pyx_L3_error)
    } else {
      __pyx_v_convention = __pyx_k_;
    }
    if (values[5]) {
      __pyx_v_terminationConvention = __Pyx_PyInt_As_int(values[5]); if (unlikely((__pyx_v_terminationConvention == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 19, __pyx_L3_error)
    } else {
      __pyx_v_terminationConvention = __pyx_k__2;
    }
    if (values[6]) {
      __pyx_v_dateGenerationRule = __Pyx_PyInt_As_int(values[6]); if (unlikely((__pyx_v_dateGenerationRule == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 20, __pyx_L3_error)
    } else {
      __pyx_v_dateGenerationRule = __pyx_k__3;
    }
    if (values[7]) {
      __pyx_v_endOfMonth = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_endOfMonth == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 21, __pyx_L3_error)
    } else {

      /* "ultron/tradingday/Schedule.pyx":21
 *                  int terminationConvention=BizDayConventions.Following,
 *                  int dateGenerationRule=DateGeneration.Forward,
 *                  bint endOfMonth=False,             # <<<<<<<<<<<<<<
 *                  Date firstDate=None,
 *                  Date nextToLastDate=None):
 */
      __pyx_v_endOfMonth = ((int)0);
    }
    __pyx_v_firstDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)values[8]);
    __pyx_v_nextToLastDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)values[9]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 4, 10, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 13, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_effectiveDate), __pyx_ptype_6ultron_10tradingday_4Date_Date, 1, "effectiveDate", 0))) __PYX_ERR(0, 14, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_terminationDate), __pyx_ptype_6ultron_10tradingday_4Date_Date, 1, "terminationDate", 0))) __PYX_ERR(0, 15, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tenor), __pyx_ptype_6ultron_10tradingday_6Period_Period, 1, "tenor", 0))) __PYX_ERR(0, 16, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_calendar), __pyx_ptype_6ultron_10tradingday_8Calendar_Calendar, 1, "calendar", 0))) __PYX_ERR(0, 17, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_firstDate), __pyx_ptype_6ultron_10tradingday_4Date_Date, 1, "firstDate", 0))) __PYX_ERR(0, 22, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_nextToLastDate), __pyx_ptype_6ultron_10tradingday_4Date_Date, 1, "nextToLastDate", 0))) __PYX_ERR(0, 23, __pyx_L1_error)
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule___init__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), __pyx_v_effectiveDate, __pyx_v_terminationDate, __pyx_v_tenor, __pyx_v_calendar, __pyx_v_convention, __pyx_v_terminationConvention, __pyx_v_dateGenerationRule, __pyx_v_endOfMonth, __pyx_v_firstDate, __pyx_v_nextToLastDate);

  /* "ultron/tradingday/Schedule.pyx":13
 * cdef class Schedule(object):
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  Date effectiveDate,
 *                  Date terminationDate,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule___init__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_effectiveDate, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_terminationDate, struct __pyx_obj_6ultron_10tradingday_6Period_Period *__pyx_v_tenor, struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *__pyx_v_calendar, int __pyx_v_convention, int __pyx_v_terminationConvention, int __pyx_v_dateGenerationRule, int __pyx_v_endOfMonth, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_firstDate, struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_nextToLastDate) {
  int __pyx_v_i;
  size_t __pyx_v_dateLen;
  struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *__pyx_v_nullCalendar = 0;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_evalDate = 0;
  int __pyx_v_y;
  int __pyx_v_periods;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_seed = 0;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_temp = 0;
  struct __pyx_obj_6ultron_10tradingday_4Date_Date *__pyx_v_exitDate = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_advanceDate __pyx_t_11;
  struct __pyx_opt_args_6ultron_10tradingday_8Calendar_8Calendar_adjustDate __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  size_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_effectiveDate);

  /* "ultron/tradingday/Schedule.pyx":36
 * 
 *         # Initialize private data
 *         self._effectiveDate = effectiveDate             # <<<<<<<<<<<<<<
 *         self._terminationDate = terminationDate
 *         self._tenor = tenor
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_effectiveDate));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_effectiveDate));
  __Pyx_GOTREF(__pyx_v_self->_effectiveDate);
  __Pyx_DECREF(__pyx_v_self->_effectiveDate);
  __pyx_v_self->_effectiveDate = ((PyObject *)__pyx_v_effectiveDate);

  /* "ultron/tradingday/Schedule.pyx":37
 *         # Initialize private data
 *         self._effectiveDate = effectiveDate
 *         self._terminationDate = terminationDate             # <<<<<<<<<<<<<<
 *         self._tenor = tenor
 *         self._cal = calendar
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_terminationDate));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_terminationDate));
  __Pyx_GOTREF(__pyx_v_self->_terminationDate);
  __Pyx_DECREF(__pyx_v_self->_terminationDate);
  __pyx_v_self->_terminationDate = ((PyObject *)__pyx_v_terminationDate);

  /* "ultron/tradingday/Schedule.pyx":38
 *         self._effectiveDate = effectiveDate
 *         self._terminationDate = terminationDate
 *         self._tenor = tenor             # <<<<<<<<<<<<<<
 *         self._cal = calendar
 *         self._convention = convention
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_tenor));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_tenor));
  __Pyx_GOTREF(__pyx_v_self->_tenor);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_tenor));
  __pyx_v_self->_tenor = __pyx_v_tenor;

  /* "ultron/tradingday/Schedule.pyx":39
 *         self._terminationDate = terminationDate
 *         self._tenor = tenor
 *         self._cal = calendar             # <<<<<<<<<<<<<<
 *         self._convention = convention
 *         self._terminationConvention = terminationConvention
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_calendar));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_calendar));
  __Pyx_GOTREF(__pyx_v_self->_cal);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_cal));
  __pyx_v_self->_cal = __pyx_v_calendar;

  /* "ultron/tradingday/Schedule.pyx":40
 *         self._tenor = tenor
 *         self._cal = calendar
 *         self._convention = convention             # <<<<<<<<<<<<<<
 *         self._terminationConvention = terminationConvention
 *         self._rule = dateGenerationRule
 */
  __pyx_v_self->_convention = __pyx_v_convention;

  /* "ultron/tradingday/Schedule.pyx":41
 *         self._cal = calendar
 *         self._convention = convention
 *         self._terminationConvention = terminationConvention             # <<<<<<<<<<<<<<
 *         self._rule = dateGenerationRule
 *         self._dates = []
 */
  __pyx_v_self->_terminationConvention = __pyx_v_terminationConvention;

  /* "ultron/tradingday/Schedule.pyx":42
 *         self._convention = convention
 *         self._terminationConvention = terminationConvention
 *         self._rule = dateGenerationRule             # <<<<<<<<<<<<<<
 *         self._dates = []
 *         self._isRegular = []
 */
  __pyx_v_self->_rule = __pyx_v_dateGenerationRule;

  /* "ultron/tradingday/Schedule.pyx":43
 *         self._terminationConvention = terminationConvention
 *         self._rule = dateGenerationRule
 *         self._dates = []             # <<<<<<<<<<<<<<
 *         self._isRegular = []
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_dates);
  __Pyx_DECREF(__pyx_v_self->_dates);
  __pyx_v_self->_dates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ultron/tradingday/Schedule.pyx":44
 *         self._rule = dateGenerationRule
 *         self._dates = []
 *         self._isRegular = []             # <<<<<<<<<<<<<<
 * 
 *         if tenor < Period("1M"):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_isRegular);
  __Pyx_DECREF(__pyx_v_self->_isRegular);
  __pyx_v_self->_isRegular = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ultron/tradingday/Schedule.pyx":46
 *         self._isRegular = []
 * 
 *         if tenor < Period("1M"):             # <<<<<<<<<<<<<<
 *             self._endOfMonth = False
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(((PyObject *)__pyx_v_tenor), __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":47
 * 
 *         if tenor < Period("1M"):
 *             self._endOfMonth = False             # <<<<<<<<<<<<<<
 *         else:
 *             self._endOfMonth = endOfMonth
 */
    __pyx_v_self->_endOfMonth = 0;

    /* "ultron/tradingday/Schedule.pyx":46
 *         self._isRegular = []
 * 
 *         if tenor < Period("1M"):             # <<<<<<<<<<<<<<
 *             self._endOfMonth = False
 *         else:
 */
    goto __pyx_L3;
  }

  /* "ultron/tradingday/Schedule.pyx":49
 *             self._endOfMonth = False
 *         else:
 *             self._endOfMonth = endOfMonth             # <<<<<<<<<<<<<<
 * 
 *         if not firstDate or firstDate == effectiveDate:
 */
  /*else*/ {
    __pyx_v_self->_endOfMonth = __pyx_v_endOfMonth;
  }
  __pyx_L3:;

  /* "ultron/tradingday/Schedule.pyx":51
 *             self._endOfMonth = endOfMonth
 * 
 *         if not firstDate or firstDate == effectiveDate:             # <<<<<<<<<<<<<<
 *             self._firstDate = None
 *         else:
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_firstDate)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 51, __pyx_L1_error)
  __pyx_t_5 = ((!__pyx_t_4) != 0);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = PyObject_RichCompare(((PyObject *)__pyx_v_firstDate), ((PyObject *)__pyx_v_effectiveDate), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_5;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":52
 * 
 *         if not firstDate or firstDate == effectiveDate:
 *             self._firstDate = None             # <<<<<<<<<<<<<<
 *         else:
 *             self._firstDate = firstDate
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_firstDate);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->_firstDate));
    __pyx_v_self->_firstDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None);

    /* "ultron/tradingday/Schedule.pyx":51
 *             self._endOfMonth = endOfMonth
 * 
 *         if not firstDate or firstDate == effectiveDate:             # <<<<<<<<<<<<<<
 *             self._firstDate = None
 *         else:
 */
    goto __pyx_L4;
  }

  /* "ultron/tradingday/Schedule.pyx":54
 *             self._firstDate = None
 *         else:
 *             self._firstDate = firstDate             # <<<<<<<<<<<<<<
 * 
 *         if not nextToLastDate or nextToLastDate == terminationDate:
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)__pyx_v_firstDate));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_firstDate));
    __Pyx_GOTREF(__pyx_v_self->_firstDate);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->_firstDate));
    __pyx_v_self->_firstDate = __pyx_v_firstDate;
  }
  __pyx_L4:;

  /* "ultron/tradingday/Schedule.pyx":56
 *             self._firstDate = firstDate
 * 
 *         if not nextToLastDate or nextToLastDate == terminationDate:             # <<<<<<<<<<<<<<
 *             self._nextToLastDate = None
 *         else:
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_nextToLastDate)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_t_4 = ((!__pyx_t_5) != 0);
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_2 = PyObject_RichCompare(((PyObject *)__pyx_v_nextToLastDate), ((PyObject *)__pyx_v_terminationDate), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":57
 * 
 *         if not nextToLastDate or nextToLastDate == terminationDate:
 *             self._nextToLastDate = None             # <<<<<<<<<<<<<<
 *         else:
 *             self._nextToLastDate = nextToLastDate
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_nextToLastDate);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->_nextToLastDate));
    __pyx_v_self->_nextToLastDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None);

    /* "ultron/tradingday/Schedule.pyx":56
 *             self._firstDate = firstDate
 * 
 *         if not nextToLastDate or nextToLastDate == terminationDate:             # <<<<<<<<<<<<<<
 *             self._nextToLastDate = None
 *         else:
 */
    goto __pyx_L7;
  }

  /* "ultron/tradingday/Schedule.pyx":59
 *             self._nextToLastDate = None
 *         else:
 *             self._nextToLastDate = nextToLastDate             # <<<<<<<<<<<<<<
 * 
 *         # in many cases (e.g. non-expired bonds) the effective date is not
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)__pyx_v_nextToLastDate));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_nextToLastDate));
    __Pyx_GOTREF(__pyx_v_self->_nextToLastDate);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->_nextToLastDate));
    __pyx_v_self->_nextToLastDate = __pyx_v_nextToLastDate;
  }
  __pyx_L7:;

  /* "ultron/tradingday/Schedule.pyx":63
 *         # in many cases (e.g. non-expired bonds) the effective date is not
 *         # really necessary. In these cases a decent placeholder is enough
 *         if not effectiveDate and not firstDate and dateGenerationRule == DateGeneration.Backward:             # <<<<<<<<<<<<<<
 *             evalDate = Settings.evaluationDate
 *             #require(evalDate < terminationDate, ValueError, "null effective date")
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_effectiveDate)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 63, __pyx_L1_error)
  __pyx_t_5 = ((!__pyx_t_4) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_firstDate)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 63, __pyx_L1_error)
  __pyx_t_4 = ((!__pyx_t_5) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_4 = ((__pyx_v_dateGenerationRule == Backward) != 0);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L11_bool_binop_done:;
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":64
 *         # really necessary. In these cases a decent placeholder is enough
 *         if not effectiveDate and not firstDate and dateGenerationRule == DateGeneration.Backward:
 *             evalDate = Settings.evaluationDate             # <<<<<<<<<<<<<<
 *             #require(evalDate < terminationDate, ValueError, "null effective date")
 *             if nextToLastDate:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_evaluationDate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 64, __pyx_L1_error)
    __pyx_v_evalDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "ultron/tradingday/Schedule.pyx":66
 *             evalDate = Settings.evaluationDate
 *             #require(evalDate < terminationDate, ValueError, "null effective date")
 *             if nextToLastDate:             # <<<<<<<<<<<<<<
 *                 y = int((nextToLastDate - evalDate) / 366) + 1
 *                 effectiveDate = nextToLastDate - Period(length=y, units=TimeUnits.Years)
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_nextToLastDate)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 66, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":67
 *             #require(evalDate < terminationDate, ValueError, "null effective date")
 *             if nextToLastDate:
 *                 y = int((nextToLastDate - evalDate) / 366) + 1             # <<<<<<<<<<<<<<
 *                 effectiveDate = nextToLastDate - Period(length=y, units=TimeUnits.Years)
 *             else:
 */
      __pyx_t_1 = PyNumber_Subtract(((PyObject *)__pyx_v_nextToLastDate), ((PyObject *)__pyx_v_evalDate)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_int_366); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 67, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_y = __pyx_t_6;

      /* "ultron/tradingday/Schedule.pyx":68
 *             if nextToLastDate:
 *                 y = int((nextToLastDate - evalDate) / 366) + 1
 *                 effectiveDate = nextToLastDate - Period(length=y, units=TimeUnits.Years)             # <<<<<<<<<<<<<<
 *             else:
 *                 y = int((terminationDate - evalDate) / 366) + 1
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_y); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_length, __pyx_t_1) < 0) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_enum__TimeUnits(Years); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_units, __pyx_t_1) < 0) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_Subtract(((PyObject *)__pyx_v_nextToLastDate), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 68, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_effectiveDate, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":66
 *             evalDate = Settings.evaluationDate
 *             #require(evalDate < terminationDate, ValueError, "null effective date")
 *             if nextToLastDate:             # <<<<<<<<<<<<<<
 *                 y = int((nextToLastDate - evalDate) / 366) + 1
 *                 effectiveDate = nextToLastDate - Period(length=y, units=TimeUnits.Years)
 */
      goto __pyx_L14;
    }

    /* "ultron/tradingday/Schedule.pyx":70
 *                 effectiveDate = nextToLastDate - Period(length=y, units=TimeUnits.Years)
 *             else:
 *                 y = int((terminationDate - evalDate) / 366) + 1             # <<<<<<<<<<<<<<
 *                 effectiveDate = terminationDate - Period(length=y, units=TimeUnits.Years)
 *         else:
 */
    /*else*/ {
      __pyx_t_2 = PyNumber_Subtract(((PyObject *)__pyx_v_terminationDate), ((PyObject *)__pyx_v_evalDate)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 70, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_int_366); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 70, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 70, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_y = __pyx_t_6;

      /* "ultron/tradingday/Schedule.pyx":71
 *             else:
 *                 y = int((terminationDate - evalDate) / 366) + 1
 *                 effectiveDate = terminationDate - Period(length=y, units=TimeUnits.Years)             # <<<<<<<<<<<<<<
 *         else:
 *             pass
 */
      __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_y); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_length, __pyx_t_2) < 0) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyInt_From_enum__TimeUnits(Years); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_units, __pyx_t_2) < 0) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Subtract(((PyObject *)__pyx_v_terminationDate), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 71, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_effectiveDate, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1));
      __pyx_t_1 = 0;
    }
    __pyx_L14:;

    /* "ultron/tradingday/Schedule.pyx":63
 *         # in many cases (e.g. non-expired bonds) the effective date is not
 *         # really necessary. In these cases a decent placeholder is enough
 *         if not effectiveDate and not firstDate and dateGenerationRule == DateGeneration.Backward:             # <<<<<<<<<<<<<<
 *             evalDate = Settings.evaluationDate
 *             #require(evalDate < terminationDate, ValueError, "null effective date")
 */
    goto __pyx_L10;
  }

  /* "ultron/tradingday/Schedule.pyx":73
 *                 effectiveDate = terminationDate - Period(length=y, units=TimeUnits.Years)
 *         else:
 *             pass             # <<<<<<<<<<<<<<
 *             #require(effectiveDate, ValueError, "null effective date")
 * 
 */
  /*else*/ {
  }
  __pyx_L10:;

  /* "ultron/tradingday/Schedule.pyx":80
 *         #.format(effectiveDate, terminationDate))
 * 
 *         if tenor.length() == 0:             # <<<<<<<<<<<<<<
 *             self._rule = DateGeneration.Zero
 *         else:
 */
  __pyx_t_3 = ((((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_tenor->__pyx_vtab)->length(__pyx_v_tenor, 0) == 0) != 0);
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":81
 * 
 *         if tenor.length() == 0:
 *             self._rule = DateGeneration.Zero             # <<<<<<<<<<<<<<
 *         else:
 *             pass
 */
    __pyx_v_self->_rule = Zero;

    /* "ultron/tradingday/Schedule.pyx":80
 *         #.format(effectiveDate, terminationDate))
 * 
 *         if tenor.length() == 0:             # <<<<<<<<<<<<<<
 *             self._rule = DateGeneration.Zero
 *         else:
 */
    goto __pyx_L15;
  }

  /* "ultron/tradingday/Schedule.pyx":83
 *             self._rule = DateGeneration.Zero
 *         else:
 *             pass             # <<<<<<<<<<<<<<
 *             #require(tenor.length() > 0, ValueError, "non positive tenor ({0:d}) not allowed".format(tenor.length()))
 * 
 */
  /*else*/ {
  }
  __pyx_L15:;

  /* "ultron/tradingday/Schedule.pyx":86
 *             #require(tenor.length() > 0, ValueError, "non positive tenor ({0:d}) not allowed".format(tenor.length()))
 * 
 *         if self._firstDate:             # <<<<<<<<<<<<<<
 *             if self._rule == DateGeneration.Backward or self._rule == DateGeneration.Forward:
 *                 pass
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_firstDate)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 86, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":87
 * 
 *         if self._firstDate:
 *             if self._rule == DateGeneration.Backward or self._rule == DateGeneration.Forward:             # <<<<<<<<<<<<<<
 *                 pass
 *                 #require(effectiveDate < self._firstDate < terminationDate, ValueError,
 */
    switch (__pyx_v_self->_rule) {
      case Backward:
      case Forward:
      break;
      case Zero:

      /* "ultron/tradingday/Schedule.pyx":95
 *                 # verified after adjustment
 *             elif self._rule == DateGeneration.Zero:
 *                 raise ValueError("first date incompatible with {0:d} date generation rule".format(self._rule))             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError("unknown rule ({0:d})".format(self._rule))
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_first_date_incompatible_with_0_d, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 95, __pyx_L1_error)

      /* "ultron/tradingday/Schedule.pyx":94
 *                 # we should ensure that the above condition is still
 *                 # verified after adjustment
 *             elif self._rule == DateGeneration.Zero:             # <<<<<<<<<<<<<<
 *                 raise ValueError("first date incompatible with {0:d} date generation rule".format(self._rule))
 *             else:
 */
      break;
      default:

      /* "ultron/tradingday/Schedule.pyx":97
 *                 raise ValueError("first date incompatible with {0:d} date generation rule".format(self._rule))
 *             else:
 *                 raise ValueError("unknown rule ({0:d})".format(self._rule))             # <<<<<<<<<<<<<<
 * 
 *         if self._nextToLastDate:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_unknown_rule_0_d, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_2 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 97, __pyx_L1_error)
      break;
    }

    /* "ultron/tradingday/Schedule.pyx":86
 *             #require(tenor.length() > 0, ValueError, "non positive tenor ({0:d}) not allowed".format(tenor.length()))
 * 
 *         if self._firstDate:             # <<<<<<<<<<<<<<
 *             if self._rule == DateGeneration.Backward or self._rule == DateGeneration.Forward:
 *                 pass
 */
  }

  /* "ultron/tradingday/Schedule.pyx":99
 *                 raise ValueError("unknown rule ({0:d})".format(self._rule))
 * 
 *         if self._nextToLastDate:             # <<<<<<<<<<<<<<
 *             if self._rule == DateGeneration.Backward or self._rule == DateGeneration.Forward:
 *                 pass
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_nextToLastDate)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 99, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":100
 * 
 *         if self._nextToLastDate:
 *             if self._rule == DateGeneration.Backward or self._rule == DateGeneration.Forward:             # <<<<<<<<<<<<<<
 *                 pass
 *                 #require(effectiveDate < self._nextToLastDate < terminationDate, ValueError,
 */
    switch (__pyx_v_self->_rule) {
      case Backward:
      case Forward:
      break;
      case Zero:

      /* "ultron/tradingday/Schedule.pyx":108
 *                 # verified after adjustment
 *             elif self._rule == DateGeneration.Zero:
 *                 raise ValueError("next to last date incompatible with {0:d} date generation rule".format(self._rule))             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError("unknown rule ({0:d})".format(self._rule))
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_next_to_last_date_incompatible_w, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 108, __pyx_L1_error)

      /* "ultron/tradingday/Schedule.pyx":107
 *                 # we should ensure that the above condition is still
 *                 # verified after adjustment
 *             elif self._rule == DateGeneration.Zero:             # <<<<<<<<<<<<<<
 *                 raise ValueError("next to last date incompatible with {0:d} date generation rule".format(self._rule))
 *             else:
 */
      break;
      default:

      /* "ultron/tradingday/Schedule.pyx":110
 *                 raise ValueError("next to last date incompatible with {0:d} date generation rule".format(self._rule))
 *             else:
 *                 raise ValueError("unknown rule ({0:d})".format(self._rule))             # <<<<<<<<<<<<<<
 * 
 *         # calendar needed for endOfMonth adjustment
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_unknown_rule_0_d, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_2 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 110, __pyx_L1_error)
      break;
    }

    /* "ultron/tradingday/Schedule.pyx":99
 *                 raise ValueError("unknown rule ({0:d})".format(self._rule))
 * 
 *         if self._nextToLastDate:             # <<<<<<<<<<<<<<
 *             if self._rule == DateGeneration.Backward or self._rule == DateGeneration.Forward:
 *                 pass
 */
  }

  /* "ultron/tradingday/Schedule.pyx":113
 * 
 *         # calendar needed for endOfMonth adjustment
 *         nullCalendar = Calendar("Null")             # <<<<<<<<<<<<<<
 *         periods = 1
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_8Calendar_Calendar), __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_nullCalendar = ((struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ultron/tradingday/Schedule.pyx":114
 *         # calendar needed for endOfMonth adjustment
 *         nullCalendar = Calendar("Null")
 *         periods = 1             # <<<<<<<<<<<<<<
 * 
 *         if self._rule == DateGeneration.Zero:
 */
  __pyx_v_periods = 1;

  /* "ultron/tradingday/Schedule.pyx":116
 *         periods = 1
 * 
 *         if self._rule == DateGeneration.Zero:             # <<<<<<<<<<<<<<
 *             self._tenor = Period(length=0, units=TimeUnits.Years)
 *             self._dates.extend([effectiveDate, terminationDate])
 */
  switch (__pyx_v_self->_rule) {
    case Zero:

    /* "ultron/tradingday/Schedule.pyx":117
 * 
 *         if self._rule == DateGeneration.Zero:
 *             self._tenor = Period(length=0, units=TimeUnits.Years)             # <<<<<<<<<<<<<<
 *             self._dates.extend([effectiveDate, terminationDate])
 *             self._isRegular.append(True)
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_length, __pyx_int_0) < 0) __PYX_ERR(0, 117, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyInt_From_enum__TimeUnits(Years); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_units, __pyx_t_2) < 0) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_tenor);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->_tenor));
    __pyx_v_self->_tenor = ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":118
 *         if self._rule == DateGeneration.Zero:
 *             self._tenor = Period(length=0, units=TimeUnits.Years)
 *             self._dates.extend([effectiveDate, terminationDate])             # <<<<<<<<<<<<<<
 *             self._isRegular.append(True)
 *         elif self._rule == DateGeneration.Backward:
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "extend");
      __PYX_ERR(0, 118, __pyx_L1_error)
    }
    __pyx_t_9 = __Pyx_ListComp_Append(__pyx_v_self->_dates, ((PyObject *)__pyx_v_effectiveDate)); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 118, __pyx_L1_error)
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "extend");
      __PYX_ERR(0, 118, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_dates, ((PyObject *)__pyx_v_terminationDate)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 118, __pyx_L1_error)
    (void)((__pyx_t_9 | __pyx_t_10));

    /* "ultron/tradingday/Schedule.pyx":119
 *             self._tenor = Period(length=0, units=TimeUnits.Years)
 *             self._dates.extend([effectiveDate, terminationDate])
 *             self._isRegular.append(True)             # <<<<<<<<<<<<<<
 *         elif self._rule == DateGeneration.Backward:
 *             self._dates.append(terminationDate)
 */
    if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 119, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_isRegular, Py_True); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 119, __pyx_L1_error)

    /* "ultron/tradingday/Schedule.pyx":116
 *         periods = 1
 * 
 *         if self._rule == DateGeneration.Zero:             # <<<<<<<<<<<<<<
 *             self._tenor = Period(length=0, units=TimeUnits.Years)
 *             self._dates.extend([effectiveDate, terminationDate])
 */
    break;
    case Backward:

    /* "ultron/tradingday/Schedule.pyx":121
 *             self._isRegular.append(True)
 *         elif self._rule == DateGeneration.Backward:
 *             self._dates.append(terminationDate)             # <<<<<<<<<<<<<<
 *             seed = terminationDate
 *             if self._nextToLastDate:
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 121, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_dates, ((PyObject *)__pyx_v_terminationDate)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 121, __pyx_L1_error)

    /* "ultron/tradingday/Schedule.pyx":122
 *         elif self._rule == DateGeneration.Backward:
 *             self._dates.append(terminationDate)
 *             seed = terminationDate             # <<<<<<<<<<<<<<
 *             if self._nextToLastDate:
 *                 self._dates.insert(0, self._nextToLastDate)
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_terminationDate));
    __pyx_v_seed = __pyx_v_terminationDate;

    /* "ultron/tradingday/Schedule.pyx":123
 *             self._dates.append(terminationDate)
 *             seed = terminationDate
 *             if self._nextToLastDate:             # <<<<<<<<<<<<<<
 *                 self._dates.insert(0, self._nextToLastDate)
 *                 temp = nullCalendar.advanceDate(seed,
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_nextToLastDate)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 123, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":124
 *             seed = terminationDate
 *             if self._nextToLastDate:
 *                 self._dates.insert(0, self._nextToLastDate)             # <<<<<<<<<<<<<<
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
        __PYX_ERR(0, 124, __pyx_L1_error)
      }
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_nextToLastDate);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_10 = PyList_Insert(__pyx_v_self->_dates, 0, __pyx_t_2); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":126
 *                 self._dates.insert(0, self._nextToLastDate)
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),             # <<<<<<<<<<<<<<
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._nextToLastDate:
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyInt_From_int(((-__pyx_v_periods) * ((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->length(__pyx_v_self->_tenor, 0))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_length, __pyx_t_1) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->units(__pyx_v_self->_tenor, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_units, __pyx_t_1) < 0) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":125
 *             if self._nextToLastDate:
 *                 self._dates.insert(0, self._nextToLastDate)
 *                 temp = nullCalendar.advanceDate(seed,             # <<<<<<<<<<<<<<
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 */
      __pyx_t_11.__pyx_n = 2;
      __pyx_t_11.c = __pyx_v_convention;
      __pyx_t_11.endOfMonth = __pyx_v_self->_endOfMonth;
      __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_nullCalendar->__pyx_vtab)->advanceDate(__pyx_v_nullCalendar, __pyx_v_seed, ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)__pyx_t_1), 0, &__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 125, __pyx_L1_error)
      __pyx_v_temp = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":128
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._nextToLastDate:             # <<<<<<<<<<<<<<
 *                     self._isRegular.insert(0, False)
 *                 else:
 */
      __pyx_t_2 = PyObject_RichCompare(((PyObject *)__pyx_v_temp), ((PyObject *)__pyx_v_self->_nextToLastDate), Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 128, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 128, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_3) {

        /* "ultron/tradingday/Schedule.pyx":129
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._nextToLastDate:
 *                     self._isRegular.insert(0, False)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._isRegular.insert(0, True)
 */
        if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
          __PYX_ERR(0, 129, __pyx_L1_error)
        }
        __pyx_t_10 = PyList_Insert(__pyx_v_self->_isRegular, 0, Py_False); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 129, __pyx_L1_error)

        /* "ultron/tradingday/Schedule.pyx":128
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._nextToLastDate:             # <<<<<<<<<<<<<<
 *                     self._isRegular.insert(0, False)
 *                 else:
 */
        goto __pyx_L19;
      }

      /* "ultron/tradingday/Schedule.pyx":131
 *                     self._isRegular.insert(0, False)
 *                 else:
 *                     self._isRegular.insert(0, True)             # <<<<<<<<<<<<<<
 *                 seed = self._nextToLastDate
 * 
 */
      /*else*/ {
        if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
          __PYX_ERR(0, 131, __pyx_L1_error)
        }
        __pyx_t_10 = PyList_Insert(__pyx_v_self->_isRegular, 0, Py_True); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 131, __pyx_L1_error)
      }
      __pyx_L19:;

      /* "ultron/tradingday/Schedule.pyx":132
 *                 else:
 *                     self._isRegular.insert(0, True)
 *                 seed = self._nextToLastDate             # <<<<<<<<<<<<<<
 * 
 *             exitDate = effectiveDate
 */
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_nextToLastDate);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_seed, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":123
 *             self._dates.append(terminationDate)
 *             seed = terminationDate
 *             if self._nextToLastDate:             # <<<<<<<<<<<<<<
 *                 self._dates.insert(0, self._nextToLastDate)
 *                 temp = nullCalendar.advanceDate(seed,
 */
    }

    /* "ultron/tradingday/Schedule.pyx":134
 *                 seed = self._nextToLastDate
 * 
 *             exitDate = effectiveDate             # <<<<<<<<<<<<<<
 *             if self._firstDate:
 *                 exitDate = self._firstDate
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_effectiveDate));
    __pyx_v_exitDate = __pyx_v_effectiveDate;

    /* "ultron/tradingday/Schedule.pyx":135
 * 
 *             exitDate = effectiveDate
 *             if self._firstDate:             # <<<<<<<<<<<<<<
 *                 exitDate = self._firstDate
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_firstDate)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 135, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":136
 *             exitDate = effectiveDate
 *             if self._firstDate:
 *                 exitDate = self._firstDate             # <<<<<<<<<<<<<<
 * 
 *             while True:
 */
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_firstDate);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_exitDate, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":135
 * 
 *             exitDate = effectiveDate
 *             if self._firstDate:             # <<<<<<<<<<<<<<
 *                 exitDate = self._firstDate
 * 
 */
    }

    /* "ultron/tradingday/Schedule.pyx":138
 *                 exitDate = self._firstDate
 * 
 *             while True:             # <<<<<<<<<<<<<<
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 */
    while (1) {

      /* "ultron/tradingday/Schedule.pyx":140
 *             while True:
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),             # <<<<<<<<<<<<<<
 *                                                 convention, self._endOfMonth)
 *                 if temp < exitDate:
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyInt_From_int(((-__pyx_v_periods) * ((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->length(__pyx_v_self->_tenor, 0))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_length, __pyx_t_1) < 0) __PYX_ERR(0, 140, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->units(__pyx_v_self->_tenor, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_units, __pyx_t_1) < 0) __PYX_ERR(0, 140, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":139
 * 
 *             while True:
 *                 temp = nullCalendar.advanceDate(seed,             # <<<<<<<<<<<<<<
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 */
      __pyx_t_11.__pyx_n = 2;
      __pyx_t_11.c = __pyx_v_convention;
      __pyx_t_11.endOfMonth = __pyx_v_self->_endOfMonth;
      __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_nullCalendar->__pyx_vtab)->advanceDate(__pyx_v_nullCalendar, __pyx_v_seed, ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)__pyx_t_1), 0, &__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 139, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_temp, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":142
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp < exitDate:             # <<<<<<<<<<<<<<
 *                     if self._firstDate and self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(
 *                             self._firstDate, convention):
 */
      __pyx_t_2 = PyObject_RichCompare(((PyObject *)__pyx_v_temp), ((PyObject *)__pyx_v_exitDate), Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 142, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 142, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_3) {

        /* "ultron/tradingday/Schedule.pyx":143
 *                                                 convention, self._endOfMonth)
 *                 if temp < exitDate:
 *                     if self._firstDate and self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(             # <<<<<<<<<<<<<<
 *                             self._firstDate, convention):
 *                         self._dates.insert(0, self._firstDate)
 */
        __pyx_t_4 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_firstDate)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 143, __pyx_L1_error)
        if (__pyx_t_4) {
        } else {
          __pyx_t_3 = __pyx_t_4;
          goto __pyx_L25_bool_binop_done;
        }
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 143, __pyx_L1_error)
        }
        __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 143, __pyx_L1_error)
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_1 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2), 0, &__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ultron/tradingday/Schedule.pyx":144
 *                 if temp < exitDate:
 *                     if self._firstDate and self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(
 *                             self._firstDate, convention):             # <<<<<<<<<<<<<<
 *                         self._dates.insert(0, self._firstDate)
 *                         self._isRegular.insert(0, False)
 */
        __pyx_t_2 = ((PyObject *)__pyx_v_self->_firstDate);
        __Pyx_INCREF(__pyx_t_2);

        /* "ultron/tradingday/Schedule.pyx":143
 *                                                 convention, self._endOfMonth)
 *                 if temp < exitDate:
 *                     if self._firstDate and self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(             # <<<<<<<<<<<<<<
 *                             self._firstDate, convention):
 *                         self._dates.insert(0, self._firstDate)
 */
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_7 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2), 0, &__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 143, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_7, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 143, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_3 = __pyx_t_4;
        __pyx_L25_bool_binop_done:;
        if (__pyx_t_3) {

          /* "ultron/tradingday/Schedule.pyx":145
 *                     if self._firstDate and self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(
 *                             self._firstDate, convention):
 *                         self._dates.insert(0, self._firstDate)             # <<<<<<<<<<<<<<
 *                         self._isRegular.insert(0, False)
 *                     break
 */
          if (unlikely(__pyx_v_self->_dates == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
            __PYX_ERR(0, 145, __pyx_L1_error)
          }
          __pyx_t_2 = ((PyObject *)__pyx_v_self->_firstDate);
          __Pyx_INCREF(__pyx_t_2);
          __pyx_t_10 = PyList_Insert(__pyx_v_self->_dates, 0, __pyx_t_2); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 145, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "ultron/tradingday/Schedule.pyx":146
 *                             self._firstDate, convention):
 *                         self._dates.insert(0, self._firstDate)
 *                         self._isRegular.insert(0, False)             # <<<<<<<<<<<<<<
 *                     break
 *                 else:
 */
          if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
            __PYX_ERR(0, 146, __pyx_L1_error)
          }
          __pyx_t_10 = PyList_Insert(__pyx_v_self->_isRegular, 0, Py_False); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 146, __pyx_L1_error)

          /* "ultron/tradingday/Schedule.pyx":143
 *                                                 convention, self._endOfMonth)
 *                 if temp < exitDate:
 *                     if self._firstDate and self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(             # <<<<<<<<<<<<<<
 *                             self._firstDate, convention):
 *                         self._dates.insert(0, self._firstDate)
 */
        }

        /* "ultron/tradingday/Schedule.pyx":147
 *                         self._dates.insert(0, self._firstDate)
 *                         self._isRegular.insert(0, False)
 *                     break             # <<<<<<<<<<<<<<
 *                 else:
 *                     # skip dates that would result in duplicates
 */
        goto __pyx_L22_break;

        /* "ultron/tradingday/Schedule.pyx":142
 *                                                 Period(length=-periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp < exitDate:             # <<<<<<<<<<<<<<
 *                     if self._firstDate and self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(
 *                             self._firstDate, convention):
 */
      }

      /* "ultron/tradingday/Schedule.pyx":151
 *                     # skip dates that would result in duplicates
 *                     # after adjustment
 *                     if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(temp, convention):             # <<<<<<<<<<<<<<
 *                         self._dates.insert(0, temp)
 *                         self._isRegular.insert(0, True)
 */
      /*else*/ {
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 151, __pyx_L1_error)
        }
        __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 151, __pyx_L1_error)
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_7 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2), 0, &__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, __pyx_v_temp, 0, &__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_7, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 151, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 151, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_3) {

          /* "ultron/tradingday/Schedule.pyx":152
 *                     # after adjustment
 *                     if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(temp, convention):
 *                         self._dates.insert(0, temp)             # <<<<<<<<<<<<<<
 *                         self._isRegular.insert(0, True)
 *                     periods += 1
 */
          if (unlikely(__pyx_v_self->_dates == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
            __PYX_ERR(0, 152, __pyx_L1_error)
          }
          __pyx_t_10 = PyList_Insert(__pyx_v_self->_dates, 0, ((PyObject *)__pyx_v_temp)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 152, __pyx_L1_error)

          /* "ultron/tradingday/Schedule.pyx":153
 *                     if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(temp, convention):
 *                         self._dates.insert(0, temp)
 *                         self._isRegular.insert(0, True)             # <<<<<<<<<<<<<<
 *                     periods += 1
 * 
 */
          if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
            __PYX_ERR(0, 153, __pyx_L1_error)
          }
          __pyx_t_10 = PyList_Insert(__pyx_v_self->_isRegular, 0, Py_True); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 153, __pyx_L1_error)

          /* "ultron/tradingday/Schedule.pyx":151
 *                     # skip dates that would result in duplicates
 *                     # after adjustment
 *                     if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(temp, convention):             # <<<<<<<<<<<<<<
 *                         self._dates.insert(0, temp)
 *                         self._isRegular.insert(0, True)
 */
        }

        /* "ultron/tradingday/Schedule.pyx":154
 *                         self._dates.insert(0, temp)
 *                         self._isRegular.insert(0, True)
 *                     periods += 1             # <<<<<<<<<<<<<<
 * 
 *             if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(effectiveDate, convention):
 */
        __pyx_v_periods = (__pyx_v_periods + 1);
      }
    }
    __pyx_L22_break:;

    /* "ultron/tradingday/Schedule.pyx":156
 *                     periods += 1
 * 
 *             if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(effectiveDate, convention):             # <<<<<<<<<<<<<<
 *                 self._dates.insert(0, effectiveDate)
 *                 self._isRegular.insert(0, False)
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 156, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 156, __pyx_L1_error)
    __pyx_t_12.__pyx_n = 1;
    __pyx_t_12.c = __pyx_v_convention;
    __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1), 0, &__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12.__pyx_n = 1;
    __pyx_t_12.c = __pyx_v_convention;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, __pyx_v_effectiveDate, 0, &__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 156, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 156, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":157
 * 
 *             if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(effectiveDate, convention):
 *                 self._dates.insert(0, effectiveDate)             # <<<<<<<<<<<<<<
 *                 self._isRegular.insert(0, False)
 * 
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
        __PYX_ERR(0, 157, __pyx_L1_error)
      }
      __pyx_t_10 = PyList_Insert(__pyx_v_self->_dates, 0, ((PyObject *)__pyx_v_effectiveDate)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 157, __pyx_L1_error)

      /* "ultron/tradingday/Schedule.pyx":158
 *             if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(effectiveDate, convention):
 *                 self._dates.insert(0, effectiveDate)
 *                 self._isRegular.insert(0, False)             # <<<<<<<<<<<<<<
 * 
 *         elif self._rule == DateGeneration.Forward:
 */
      if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "insert");
        __PYX_ERR(0, 158, __pyx_L1_error)
      }
      __pyx_t_10 = PyList_Insert(__pyx_v_self->_isRegular, 0, Py_False); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 158, __pyx_L1_error)

      /* "ultron/tradingday/Schedule.pyx":156
 *                     periods += 1
 * 
 *             if self._cal.adjustDate(self._dates[0], convention) != self._cal.adjustDate(effectiveDate, convention):             # <<<<<<<<<<<<<<
 *                 self._dates.insert(0, effectiveDate)
 *                 self._isRegular.insert(0, False)
 */
    }

    /* "ultron/tradingday/Schedule.pyx":120
 *             self._dates.extend([effectiveDate, terminationDate])
 *             self._isRegular.append(True)
 *         elif self._rule == DateGeneration.Backward:             # <<<<<<<<<<<<<<
 *             self._dates.append(terminationDate)
 *             seed = terminationDate
 */
    break;
    case Forward:

    /* "ultron/tradingday/Schedule.pyx":161
 * 
 *         elif self._rule == DateGeneration.Forward:
 *             self._dates.append(effectiveDate)             # <<<<<<<<<<<<<<
 * 
 *             seed = self._dates[-1]
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 161, __pyx_L1_error)
    }
    __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_dates, ((PyObject *)__pyx_v_effectiveDate)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 161, __pyx_L1_error)

    /* "ultron/tradingday/Schedule.pyx":163
 *             self._dates.append(effectiveDate)
 * 
 *             seed = self._dates[-1]             # <<<<<<<<<<<<<<
 * 
 *             if self._firstDate:
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 163, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 163, __pyx_L1_error)
    __pyx_v_seed = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "ultron/tradingday/Schedule.pyx":165
 *             seed = self._dates[-1]
 * 
 *             if self._firstDate:             # <<<<<<<<<<<<<<
 *                 self._dates.append(self._firstDate)
 *                 temp = nullCalendar.advanceDate(seed,
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_firstDate)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 165, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":166
 * 
 *             if self._firstDate:
 *                 self._dates.append(self._firstDate)             # <<<<<<<<<<<<<<
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 166, __pyx_L1_error)
      }
      __pyx_t_7 = ((PyObject *)__pyx_v_self->_firstDate);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_dates, __pyx_t_7); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 166, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "ultron/tradingday/Schedule.pyx":168
 *                 self._dates.append(self._firstDate)
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),             # <<<<<<<<<<<<<<
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._firstDate:
 */
      __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyInt_From_int((__pyx_v_periods * ((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->length(__pyx_v_self->_tenor, 0))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_length, __pyx_t_1) < 0) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->units(__pyx_v_self->_tenor, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_units, __pyx_t_1) < 0) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "ultron/tradingday/Schedule.pyx":167
 *             if self._firstDate:
 *                 self._dates.append(self._firstDate)
 *                 temp = nullCalendar.advanceDate(seed,             # <<<<<<<<<<<<<<
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 */
      __pyx_t_11.__pyx_n = 2;
      __pyx_t_11.c = __pyx_v_convention;
      __pyx_t_11.endOfMonth = __pyx_v_self->_endOfMonth;
      __pyx_t_7 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_nullCalendar->__pyx_vtab)->advanceDate(__pyx_v_nullCalendar, __pyx_v_seed, ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)__pyx_t_1), 0, &__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 167, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 167, __pyx_L1_error)
      __pyx_v_temp = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "ultron/tradingday/Schedule.pyx":170
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._firstDate:             # <<<<<<<<<<<<<<
 *                     self._isRegular.append(False)
 *                 else:
 */
      __pyx_t_7 = PyObject_RichCompare(((PyObject *)__pyx_v_temp), ((PyObject *)__pyx_v_self->_firstDate), Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 170, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 170, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_3) {

        /* "ultron/tradingday/Schedule.pyx":171
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._firstDate:
 *                     self._isRegular.append(False)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._isRegular.append(True)
 */
        if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 171, __pyx_L1_error)
        }
        __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_isRegular, Py_False); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 171, __pyx_L1_error)

        /* "ultron/tradingday/Schedule.pyx":170
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp != self._firstDate:             # <<<<<<<<<<<<<<
 *                     self._isRegular.append(False)
 *                 else:
 */
        goto __pyx_L30;
      }

      /* "ultron/tradingday/Schedule.pyx":173
 *                     self._isRegular.append(False)
 *                 else:
 *                     self._isRegular.append(True)             # <<<<<<<<<<<<<<
 *                 seed = self._firstDate
 * 
 */
      /*else*/ {
        if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
          __PYX_ERR(0, 173, __pyx_L1_error)
        }
        __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_isRegular, Py_True); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 173, __pyx_L1_error)
      }
      __pyx_L30:;

      /* "ultron/tradingday/Schedule.pyx":174
 *                 else:
 *                     self._isRegular.append(True)
 *                 seed = self._firstDate             # <<<<<<<<<<<<<<
 * 
 *             exitDate = terminationDate
 */
      __pyx_t_7 = ((PyObject *)__pyx_v_self->_firstDate);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_seed, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "ultron/tradingday/Schedule.pyx":165
 *             seed = self._dates[-1]
 * 
 *             if self._firstDate:             # <<<<<<<<<<<<<<
 *                 self._dates.append(self._firstDate)
 *                 temp = nullCalendar.advanceDate(seed,
 */
    }

    /* "ultron/tradingday/Schedule.pyx":176
 *                 seed = self._firstDate
 * 
 *             exitDate = terminationDate             # <<<<<<<<<<<<<<
 *             if self._nextToLastDate:
 *                 exitDate = self._nextToLastDate
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_terminationDate));
    __pyx_v_exitDate = __pyx_v_terminationDate;

    /* "ultron/tradingday/Schedule.pyx":177
 * 
 *             exitDate = terminationDate
 *             if self._nextToLastDate:             # <<<<<<<<<<<<<<
 *                 exitDate = self._nextToLastDate
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_nextToLastDate)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 177, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":178
 *             exitDate = terminationDate
 *             if self._nextToLastDate:
 *                 exitDate = self._nextToLastDate             # <<<<<<<<<<<<<<
 * 
 *             while True:
 */
      __pyx_t_7 = ((PyObject *)__pyx_v_self->_nextToLastDate);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_exitDate, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "ultron/tradingday/Schedule.pyx":177
 * 
 *             exitDate = terminationDate
 *             if self._nextToLastDate:             # <<<<<<<<<<<<<<
 *                 exitDate = self._nextToLastDate
 * 
 */
    }

    /* "ultron/tradingday/Schedule.pyx":180
 *                 exitDate = self._nextToLastDate
 * 
 *             while True:             # <<<<<<<<<<<<<<
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 */
    while (1) {

      /* "ultron/tradingday/Schedule.pyx":182
 *             while True:
 *                 temp = nullCalendar.advanceDate(seed,
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),             # <<<<<<<<<<<<<<
 *                                                 convention, self._endOfMonth)
 *                 if temp > exitDate:
 */
      __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyInt_From_int((__pyx_v_periods * ((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->length(__pyx_v_self->_tenor, 0))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_length, __pyx_t_1) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_int(((struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period *)__pyx_v_self->_tenor->__pyx_vtab)->units(__pyx_v_self->_tenor, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_units, __pyx_t_1) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_6Period_Period), __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "ultron/tradingday/Schedule.pyx":181
 * 
 *             while True:
 *                 temp = nullCalendar.advanceDate(seed,             # <<<<<<<<<<<<<<
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 */
      __pyx_t_11.__pyx_n = 2;
      __pyx_t_11.c = __pyx_v_convention;
      __pyx_t_11.endOfMonth = __pyx_v_self->_endOfMonth;
      __pyx_t_7 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_nullCalendar->__pyx_vtab)->advanceDate(__pyx_v_nullCalendar, __pyx_v_seed, ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)__pyx_t_1), 0, &__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 181, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 181, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_temp, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "ultron/tradingday/Schedule.pyx":184
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp > exitDate:             # <<<<<<<<<<<<<<
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],
 *                                                                      convention) != self._cal.adjustDate(
 */
      __pyx_t_7 = PyObject_RichCompare(((PyObject *)__pyx_v_temp), ((PyObject *)__pyx_v_exitDate), Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 184, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 184, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_3) {

        /* "ultron/tradingday/Schedule.pyx":185
 *                                                 convention, self._endOfMonth)
 *                 if temp > exitDate:
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],             # <<<<<<<<<<<<<<
 *                                                                      convention) != self._cal.adjustDate(
 *                             self._nextToLastDate, convention):
 */
        __pyx_t_4 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_self->_nextToLastDate)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 185, __pyx_L1_error)
        if (__pyx_t_4) {
        } else {
          __pyx_t_3 = __pyx_t_4;
          goto __pyx_L36_bool_binop_done;
        }

        /* "ultron/tradingday/Schedule.pyx":186
 *                 if temp > exitDate:
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],
 *                                                                      convention) != self._cal.adjustDate(             # <<<<<<<<<<<<<<
 *                             self._nextToLastDate, convention):
 *                         self._dates.append(self._nextToLastDate)
 */
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 185, __pyx_L1_error)
        }

        /* "ultron/tradingday/Schedule.pyx":185
 *                                                 convention, self._endOfMonth)
 *                 if temp > exitDate:
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],             # <<<<<<<<<<<<<<
 *                                                                      convention) != self._cal.adjustDate(
 *                             self._nextToLastDate, convention):
 */
        __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 185, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 185, __pyx_L1_error)

        /* "ultron/tradingday/Schedule.pyx":186
 *                 if temp > exitDate:
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],
 *                                                                      convention) != self._cal.adjustDate(             # <<<<<<<<<<<<<<
 *                             self._nextToLastDate, convention):
 *                         self._dates.append(self._nextToLastDate)
 */
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_1 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7), 0, &__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 185, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "ultron/tradingday/Schedule.pyx":187
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],
 *                                                                      convention) != self._cal.adjustDate(
 *                             self._nextToLastDate, convention):             # <<<<<<<<<<<<<<
 *                         self._dates.append(self._nextToLastDate)
 *                         self._isRegular.append(False)
 */
        __pyx_t_7 = ((PyObject *)__pyx_v_self->_nextToLastDate);
        __Pyx_INCREF(__pyx_t_7);

        /* "ultron/tradingday/Schedule.pyx":186
 *                 if temp > exitDate:
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],
 *                                                                      convention) != self._cal.adjustDate(             # <<<<<<<<<<<<<<
 *                             self._nextToLastDate, convention):
 *                         self._dates.append(self._nextToLastDate)
 */
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7), 0, &__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 186, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 186, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 186, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_3 = __pyx_t_4;
        __pyx_L36_bool_binop_done:;

        /* "ultron/tradingday/Schedule.pyx":185
 *                                                 convention, self._endOfMonth)
 *                 if temp > exitDate:
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],             # <<<<<<<<<<<<<<
 *                                                                      convention) != self._cal.adjustDate(
 *                             self._nextToLastDate, convention):
 */
        if (__pyx_t_3) {

          /* "ultron/tradingday/Schedule.pyx":188
 *                                                                      convention) != self._cal.adjustDate(
 *                             self._nextToLastDate, convention):
 *                         self._dates.append(self._nextToLastDate)             # <<<<<<<<<<<<<<
 *                         self._isRegular.append(False)
 *                     break
 */
          if (unlikely(__pyx_v_self->_dates == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 188, __pyx_L1_error)
          }
          __pyx_t_7 = ((PyObject *)__pyx_v_self->_nextToLastDate);
          __Pyx_INCREF(__pyx_t_7);
          __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_dates, __pyx_t_7); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 188, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "ultron/tradingday/Schedule.pyx":189
 *                             self._nextToLastDate, convention):
 *                         self._dates.append(self._nextToLastDate)
 *                         self._isRegular.append(False)             # <<<<<<<<<<<<<<
 *                     break
 *                 else:
 */
          if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 189, __pyx_L1_error)
          }
          __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_isRegular, Py_False); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 189, __pyx_L1_error)

          /* "ultron/tradingday/Schedule.pyx":185
 *                                                 convention, self._endOfMonth)
 *                 if temp > exitDate:
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],             # <<<<<<<<<<<<<<
 *                                                                      convention) != self._cal.adjustDate(
 *                             self._nextToLastDate, convention):
 */
        }

        /* "ultron/tradingday/Schedule.pyx":190
 *                         self._dates.append(self._nextToLastDate)
 *                         self._isRegular.append(False)
 *                     break             # <<<<<<<<<<<<<<
 *                 else:
 *                     # skip dates that would result in duplicates
 */
        goto __pyx_L33_break;

        /* "ultron/tradingday/Schedule.pyx":184
 *                                                 Period(length=periods * self._tenor.length(), units=self._tenor.units()),
 *                                                 convention, self._endOfMonth)
 *                 if temp > exitDate:             # <<<<<<<<<<<<<<
 *                     if self._nextToLastDate and self._cal.adjustDate(self._dates[-1],
 *                                                                      convention) != self._cal.adjustDate(
 */
      }

      /* "ultron/tradingday/Schedule.pyx":194
 *                     # skip dates that would result in duplicates
 *                     # after adjustment
 *                     if self._cal.adjustDate(self._dates[-1], convention) != self._cal.adjustDate(temp, convention):             # <<<<<<<<<<<<<<
 *                         self._dates.append(temp)
 *                         self._isRegular.append(True)
 */
      /*else*/ {
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 194, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 194, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 194, __pyx_L1_error)
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_7), 0, &__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 194, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_12.__pyx_n = 1;
        __pyx_t_12.c = __pyx_v_convention;
        __pyx_t_7 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, __pyx_v_temp, 0, &__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 194, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_t_7, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 194, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_3) {

          /* "ultron/tradingday/Schedule.pyx":195
 *                     # after adjustment
 *                     if self._cal.adjustDate(self._dates[-1], convention) != self._cal.adjustDate(temp, convention):
 *                         self._dates.append(temp)             # <<<<<<<<<<<<<<
 *                         self._isRegular.append(True)
 *                     periods += 1
 */
          if (unlikely(__pyx_v_self->_dates == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 195, __pyx_L1_error)
          }
          __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_dates, ((PyObject *)__pyx_v_temp)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 195, __pyx_L1_error)

          /* "ultron/tradingday/Schedule.pyx":196
 *                     if self._cal.adjustDate(self._dates[-1], convention) != self._cal.adjustDate(temp, convention):
 *                         self._dates.append(temp)
 *                         self._isRegular.append(True)             # <<<<<<<<<<<<<<
 *                     periods += 1
 * 
 */
          if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
            __PYX_ERR(0, 196, __pyx_L1_error)
          }
          __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_isRegular, Py_True); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 196, __pyx_L1_error)

          /* "ultron/tradingday/Schedule.pyx":194
 *                     # skip dates that would result in duplicates
 *                     # after adjustment
 *                     if self._cal.adjustDate(self._dates[-1], convention) != self._cal.adjustDate(temp, convention):             # <<<<<<<<<<<<<<
 *                         self._dates.append(temp)
 *                         self._isRegular.append(True)
 */
        }

        /* "ultron/tradingday/Schedule.pyx":197
 *                         self._dates.append(temp)
 *                         self._isRegular.append(True)
 *                     periods += 1             # <<<<<<<<<<<<<<
 * 
 *             if self._cal.adjustDate(self._dates[-1], terminationConvention) != self._cal.adjustDate(terminationDate,
 */
        __pyx_v_periods = (__pyx_v_periods + 1);
      }
    }
    __pyx_L33_break:;

    /* "ultron/tradingday/Schedule.pyx":199
 *                     periods += 1
 * 
 *             if self._cal.adjustDate(self._dates[-1], terminationConvention) != self._cal.adjustDate(terminationDate,             # <<<<<<<<<<<<<<
 *                                                                                                     terminationConvention):
 *                 self._dates.append(terminationDate)
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 199, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 199, __pyx_L1_error)
    __pyx_t_12.__pyx_n = 1;
    __pyx_t_12.c = __pyx_v_terminationConvention;
    __pyx_t_7 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1), 0, &__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ultron/tradingday/Schedule.pyx":200
 * 
 *             if self._cal.adjustDate(self._dates[-1], terminationConvention) != self._cal.adjustDate(terminationDate,
 *                                                                                                     terminationConvention):             # <<<<<<<<<<<<<<
 *                 self._dates.append(terminationDate)
 *                 self._isRegular.append(False)
 */
    __pyx_t_12.__pyx_n = 1;
    __pyx_t_12.c = __pyx_v_terminationConvention;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, __pyx_v_terminationDate, 0, &__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_7, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 199, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ultron/tradingday/Schedule.pyx":199
 *                     periods += 1
 * 
 *             if self._cal.adjustDate(self._dates[-1], terminationConvention) != self._cal.adjustDate(terminationDate,             # <<<<<<<<<<<<<<
 *                                                                                                     terminationConvention):
 *                 self._dates.append(terminationDate)
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 199, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":201
 *             if self._cal.adjustDate(self._dates[-1], terminationConvention) != self._cal.adjustDate(terminationDate,
 *                                                                                                     terminationConvention):
 *                 self._dates.append(terminationDate)             # <<<<<<<<<<<<<<
 *                 self._isRegular.append(False)
 *         else:
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 201, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_dates, ((PyObject *)__pyx_v_terminationDate)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 201, __pyx_L1_error)

      /* "ultron/tradingday/Schedule.pyx":202
 *                                                                                                     terminationConvention):
 *                 self._dates.append(terminationDate)
 *                 self._isRegular.append(False)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("unknown rule ({0:d})".format(self._rule))
 */
      if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 202, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_isRegular, Py_False); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 202, __pyx_L1_error)

      /* "ultron/tradingday/Schedule.pyx":199
 *                     periods += 1
 * 
 *             if self._cal.adjustDate(self._dates[-1], terminationConvention) != self._cal.adjustDate(terminationDate,             # <<<<<<<<<<<<<<
 *                                                                                                     terminationConvention):
 *                 self._dates.append(terminationDate)
 */
    }

    /* "ultron/tradingday/Schedule.pyx":160
 *                 self._isRegular.insert(0, False)
 * 
 *         elif self._rule == DateGeneration.Forward:             # <<<<<<<<<<<<<<
 *             self._dates.append(effectiveDate)
 * 
 */
    break;
    default:

    /* "ultron/tradingday/Schedule.pyx":204
 *                 self._isRegular.append(False)
 *         else:
 *             raise ValueError("unknown rule ({0:d})".format(self._rule))             # <<<<<<<<<<<<<<
 * 
 *         # adjustments
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_unknown_rule_0_d, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 204, __pyx_L1_error)
    break;
  }

  /* "ultron/tradingday/Schedule.pyx":207
 * 
 *         # adjustments
 *         if self._endOfMonth and self._cal.isEndOfMonth(seed):             # <<<<<<<<<<<<<<
 *             # adjust to end of month
 *             if convention == BizDayConventions.Unadjusted:
 */
  __pyx_t_4 = (__pyx_v_self->_endOfMonth != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L41_bool_binop_done;
  }
  if (unlikely(!__pyx_v_seed)) { __Pyx_RaiseUnboundLocalError("seed"); __PYX_ERR(0, 207, __pyx_L1_error) }
  __pyx_t_1 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->isEndOfMonth(__pyx_v_self->_cal, __pyx_v_seed, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L41_bool_binop_done:;
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":209
 *         if self._endOfMonth and self._cal.isEndOfMonth(seed):
 *             # adjust to end of month
 *             if convention == BizDayConventions.Unadjusted:             # <<<<<<<<<<<<<<
 *                 for i in range(len(self._dates) - 1):
 *                     self._dates[i] = Date.endOfMonth(self._dates[i])
 */
    __pyx_t_3 = ((__pyx_v_convention == Unadjusted) != 0);
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":210
 *             # adjust to end of month
 *             if convention == BizDayConventions.Unadjusted:
 *                 for i in range(len(self._dates) - 1):             # <<<<<<<<<<<<<<
 *                     self._dates[i] = Date.endOfMonth(self._dates[i])
 *             else:
 */
      __pyx_t_1 = __pyx_v_self->_dates;
      __Pyx_INCREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 210, __pyx_L1_error)
      }
      __pyx_t_13 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 210, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_14 = (__pyx_t_13 - 1);
      __pyx_t_13 = __pyx_t_14;
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_13; __pyx_t_6+=1) {
        __pyx_v_i = __pyx_t_6;

        /* "ultron/tradingday/Schedule.pyx":211
 *             if convention == BizDayConventions.Unadjusted:
 *                 for i in range(len(self._dates) - 1):
 *                     self._dates[i] = Date.endOfMonth(self._dates[i])             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(len(self._dates) - 1):
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6ultron_10tradingday_4Date_Date), __pyx_n_s_endOfMonth); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 211, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 211, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 211, __pyx_L1_error)
        }
        if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, __pyx_v_i, __pyx_t_1, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 211, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }

      /* "ultron/tradingday/Schedule.pyx":209
 *         if self._endOfMonth and self._cal.isEndOfMonth(seed):
 *             # adjust to end of month
 *             if convention == BizDayConventions.Unadjusted:             # <<<<<<<<<<<<<<
 *                 for i in range(len(self._dates) - 1):
 *                     self._dates[i] = Date.endOfMonth(self._dates[i])
 */
      goto __pyx_L43;
    }

    /* "ultron/tradingday/Schedule.pyx":213
 *                     self._dates[i] = Date.endOfMonth(self._dates[i])
 *             else:
 *                 for i in range(len(self._dates) - 1):             # <<<<<<<<<<<<<<
 *                     self._dates[i] = self._cal.endOfMonth(self._dates[i])
 * 
 */
    /*else*/ {
      __pyx_t_1 = __pyx_v_self->_dates;
      __Pyx_INCREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
        __PYX_ERR(0, 213, __pyx_L1_error)
      }
      __pyx_t_14 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 213, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_13 = (__pyx_t_14 - 1);
      __pyx_t_14 = __pyx_t_13;
      for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_14; __pyx_t_6+=1) {
        __pyx_v_i = __pyx_t_6;

        /* "ultron/tradingday/Schedule.pyx":214
 *             else:
 *                 for i in range(len(self._dates) - 1):
 *                     self._dates[i] = self._cal.endOfMonth(self._dates[i])             # <<<<<<<<<<<<<<
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:
 */
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 214, __pyx_L1_error)
        }
        __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 214, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 214, __pyx_L1_error)
        __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->endOfMonth(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 214, __pyx_L1_error)
        }
        if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, __pyx_v_i, __pyx_t_2, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 214, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __pyx_L43:;

    /* "ultron/tradingday/Schedule.pyx":216
 *                     self._dates[i] = self._cal.endOfMonth(self._dates[i])
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:             # <<<<<<<<<<<<<<
 *                 self._dates[0] = self._cal.endOfMonth(self._dates[0])
 *                 self._dates[-1] = self._cal.endOfMonth(self._dates[-1])
 */
    __pyx_t_3 = ((__pyx_v_terminationConvention != Unadjusted) != 0);
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":217
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:
 *                 self._dates[0] = self._cal.endOfMonth(self._dates[0])             # <<<<<<<<<<<<<<
 *                 self._dates[-1] = self._cal.endOfMonth(self._dates[-1])
 *             else:
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 217, __pyx_L1_error)
      }
      __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 217, __pyx_L1_error)
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->endOfMonth(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 217, __pyx_L1_error)
      }
      if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, 0, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ultron/tradingday/Schedule.pyx":218
 *             if terminationConvention != BizDayConventions.Unadjusted:
 *                 self._dates[0] = self._cal.endOfMonth(self._dates[0])
 *                 self._dates[-1] = self._cal.endOfMonth(self._dates[-1])             # <<<<<<<<<<<<<<
 *             else:
 *                 if self._rule == DateGeneration.Backward:
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 218, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 218, __pyx_L1_error)
      __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->endOfMonth(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 218, __pyx_L1_error)
      }
      if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, -1L, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 1, 1, 1) < 0)) __PYX_ERR(0, 218, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":216
 *                     self._dates[i] = self._cal.endOfMonth(self._dates[i])
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:             # <<<<<<<<<<<<<<
 *                 self._dates[0] = self._cal.endOfMonth(self._dates[0])
 *                 self._dates[-1] = self._cal.endOfMonth(self._dates[-1])
 */
      goto __pyx_L48;
    }

    /* "ultron/tradingday/Schedule.pyx":220
 *                 self._dates[-1] = self._cal.endOfMonth(self._dates[-1])
 *             else:
 *                 if self._rule == DateGeneration.Backward:             # <<<<<<<<<<<<<<
 *                     self._dates[-1] = Date.endOfMonth(self._dates[-1])
 *                 else:
 */
    /*else*/ {
      __pyx_t_3 = ((__pyx_v_self->_rule == Backward) != 0);
      if (__pyx_t_3) {

        /* "ultron/tradingday/Schedule.pyx":221
 *             else:
 *                 if self._rule == DateGeneration.Backward:
 *                     self._dates[-1] = Date.endOfMonth(self._dates[-1])             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._dates[0] = Date.endOfMonth(self._dates[0])
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6ultron_10tradingday_4Date_Date), __pyx_n_s_endOfMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 221, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 221, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 221, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        __pyx_t_2 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 221, __pyx_L1_error)
        }
        if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, -1L, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 1, 1, 1) < 0)) __PYX_ERR(0, 221, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ultron/tradingday/Schedule.pyx":220
 *                 self._dates[-1] = self._cal.endOfMonth(self._dates[-1])
 *             else:
 *                 if self._rule == DateGeneration.Backward:             # <<<<<<<<<<<<<<
 *                     self._dates[-1] = Date.endOfMonth(self._dates[-1])
 *                 else:
 */
        goto __pyx_L49;
      }

      /* "ultron/tradingday/Schedule.pyx":223
 *                     self._dates[-1] = Date.endOfMonth(self._dates[-1])
 *                 else:
 *                     self._dates[0] = Date.endOfMonth(self._dates[0])             # <<<<<<<<<<<<<<
 *         else:
 *             for i in range(len(self._dates) - 1):
 */
      /*else*/ {
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6ultron_10tradingday_4Date_Date), __pyx_n_s_endOfMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 223, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        __pyx_t_2 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 223, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(__pyx_v_self->_dates == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 223, __pyx_L1_error)
        }
        if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, 0, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 223, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L49:;
    }
    __pyx_L48:;

    /* "ultron/tradingday/Schedule.pyx":207
 * 
 *         # adjustments
 *         if self._endOfMonth and self._cal.isEndOfMonth(seed):             # <<<<<<<<<<<<<<
 *             # adjust to end of month
 *             if convention == BizDayConventions.Unadjusted:
 */
    goto __pyx_L40;
  }

  /* "ultron/tradingday/Schedule.pyx":225
 *                     self._dates[0] = Date.endOfMonth(self._dates[0])
 *         else:
 *             for i in range(len(self._dates) - 1):             # <<<<<<<<<<<<<<
 *                 self._dates[i] = self._cal.adjustDate(self._dates[i], convention)
 * 
 */
  /*else*/ {
    __pyx_t_2 = __pyx_v_self->_dates;
    __Pyx_INCREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 225, __pyx_L1_error)
    }
    __pyx_t_13 = PyList_GET_SIZE(__pyx_t_2); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_14 = (__pyx_t_13 - 1);
    __pyx_t_13 = __pyx_t_14;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_13; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "ultron/tradingday/Schedule.pyx":226
 *         else:
 *             for i in range(len(self._dates) - 1):
 *                 self._dates[i] = self._cal.adjustDate(self._dates[i], convention)             # <<<<<<<<<<<<<<
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 226, __pyx_L1_error)
      }
      __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 226, __pyx_L1_error)
      __pyx_t_12.__pyx_n = 1;
      __pyx_t_12.c = __pyx_v_convention;
      __pyx_t_1 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_2), 0, &__pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 226, __pyx_L1_error)
      }
      if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, __pyx_v_i, __pyx_t_1, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "ultron/tradingday/Schedule.pyx":228
 *                 self._dates[i] = self._cal.adjustDate(self._dates[i], convention)
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:             # <<<<<<<<<<<<<<
 *                 self._dates[-1] = self._cal.adjustDate(self._dates[-1], terminationConvention)
 * 
 */
    __pyx_t_3 = ((__pyx_v_terminationConvention != Unadjusted) != 0);
    if (__pyx_t_3) {

      /* "ultron/tradingday/Schedule.pyx":229
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:
 *                 self._dates[-1] = self._cal.adjustDate(self._dates[-1], terminationConvention)             # <<<<<<<<<<<<<<
 * 
 *         # Final safety checks to remove extra next-to-last date, if
 */
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 229, __pyx_L1_error)
      }
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(0, 229, __pyx_L1_error)
      __pyx_t_12.__pyx_n = 1;
      __pyx_t_12.c = __pyx_v_terminationConvention;
      __pyx_t_2 = ((struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar *)__pyx_v_self->_cal->__pyx_vtab)->adjustDate(__pyx_v_self->_cal, ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1), 0, &__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_v_self->_dates == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 229, __pyx_L1_error)
      }
      if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, -1L, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 1, 1, 1) < 0)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ultron/tradingday/Schedule.pyx":228
 *                 self._dates[i] = self._cal.adjustDate(self._dates[i], convention)
 * 
 *             if terminationConvention != BizDayConventions.Unadjusted:             # <<<<<<<<<<<<<<
 *                 self._dates[-1] = self._cal.adjustDate(self._dates[-1], terminationConvention)
 * 
 */
    }
  }
  __pyx_L40:;

  /* "ultron/tradingday/Schedule.pyx":236
 *         # for an example).
 * 
 *         dateLen = len(self._dates)             # <<<<<<<<<<<<<<
 * 
 *         if dateLen >= 2 and self._dates[dateLen - 2] >= self._dates[-1]:
 */
  __pyx_t_2 = __pyx_v_self->_dates;
  __Pyx_INCREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 236, __pyx_L1_error)
  }
  __pyx_t_14 = PyList_GET_SIZE(__pyx_t_2); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_dateLen = __pyx_t_14;

  /* "ultron/tradingday/Schedule.pyx":238
 *         dateLen = len(self._dates)
 * 
 *         if dateLen >= 2 and self._dates[dateLen - 2] >= self._dates[-1]:             # <<<<<<<<<<<<<<
 *             self._isRegular[dateLen - 2] = (self._dates[dateLen - 2] == self._dates[-1])
 *             self._dates[dateLen - 2] = self._dates[-1]
 */
  __pyx_t_4 = ((__pyx_v_dateLen >= 2) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L54_bool_binop_done;
  }
  if (unlikely(__pyx_v_self->_dates == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 238, __pyx_L1_error)
  }
  __pyx_t_15 = (__pyx_v_dateLen - 2);
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, __pyx_t_15, size_t, 0, __Pyx_PyInt_FromSize_t, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_v_self->_dates == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 238, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_GE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L54_bool_binop_done:;
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":239
 * 
 *         if dateLen >= 2 and self._dates[dateLen - 2] >= self._dates[-1]:
 *             self._isRegular[dateLen - 2] = (self._dates[dateLen - 2] == self._dates[-1])             # <<<<<<<<<<<<<<
 *             self._dates[dateLen - 2] = self._dates[-1]
 *             self._dates.pop()
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 239, __pyx_L1_error)
    }
    __pyx_t_15 = (__pyx_v_dateLen - 2);
    __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, __pyx_t_15, size_t, 0, __Pyx_PyInt_FromSize_t, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 239, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_7, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 239, __pyx_L1_error)
    }
    __pyx_t_15 = (__pyx_v_dateLen - 2);
    if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_isRegular, __pyx_t_15, __pyx_t_2, size_t, 0, __Pyx_PyInt_FromSize_t, 1, 0, 1) < 0)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":240
 *         if dateLen >= 2 and self._dates[dateLen - 2] >= self._dates[-1]:
 *             self._isRegular[dateLen - 2] = (self._dates[dateLen - 2] == self._dates[-1])
 *             self._dates[dateLen - 2] = self._dates[-1]             # <<<<<<<<<<<<<<
 *             self._dates.pop()
 *             self._isRegular.pop()
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 240, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 240, __pyx_L1_error)
    }
    __pyx_t_15 = (__pyx_v_dateLen - 2);
    if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, __pyx_t_15, __pyx_t_2, size_t, 0, __Pyx_PyInt_FromSize_t, 1, 0, 1) < 0)) __PYX_ERR(0, 240, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":241
 *             self._isRegular[dateLen - 2] = (self._dates[dateLen - 2] == self._dates[-1])
 *             self._dates[dateLen - 2] = self._dates[-1]
 *             self._dates.pop()             # <<<<<<<<<<<<<<
 *             self._isRegular.pop()
 * 
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 241, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyList_Pop(__pyx_v_self->_dates); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":242
 *             self._dates[dateLen - 2] = self._dates[-1]
 *             self._dates.pop()
 *             self._isRegular.pop()             # <<<<<<<<<<<<<<
 * 
 *         if len(self._dates) >= 2 and self._dates[1] <= self._dates[0]:
 */
    if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 242, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyList_Pop(__pyx_v_self->_isRegular); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":238
 *         dateLen = len(self._dates)
 * 
 *         if dateLen >= 2 and self._dates[dateLen - 2] >= self._dates[-1]:             # <<<<<<<<<<<<<<
 *             self._isRegular[dateLen - 2] = (self._dates[dateLen - 2] == self._dates[-1])
 *             self._dates[dateLen - 2] = self._dates[-1]
 */
  }

  /* "ultron/tradingday/Schedule.pyx":244
 *             self._isRegular.pop()
 * 
 *         if len(self._dates) >= 2 and self._dates[1] <= self._dates[0]:             # <<<<<<<<<<<<<<
 *             self._isRegular[1] = (self._dates[1] == self._dates[0])
 *             self._dates[1] = self._dates[0]
 */
  __pyx_t_2 = __pyx_v_self->_dates;
  __Pyx_INCREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 244, __pyx_L1_error)
  }
  __pyx_t_14 = PyList_GET_SIZE(__pyx_t_2); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = ((__pyx_t_14 >= 2) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L57_bool_binop_done;
  }
  if (unlikely(__pyx_v_self->_dates == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 244, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_v_self->_dates == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 244, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_LE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L57_bool_binop_done:;
  if (__pyx_t_3) {

    /* "ultron/tradingday/Schedule.pyx":245
 * 
 *         if len(self._dates) >= 2 and self._dates[1] <= self._dates[0]:
 *             self._isRegular[1] = (self._dates[1] == self._dates[0])             # <<<<<<<<<<<<<<
 *             self._dates[1] = self._dates[0]
 *             self._dates = self._dates[1:]
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 245, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 245, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_7, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 245, __pyx_L1_error)
    }
    if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_isRegular, 1, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":246
 *         if len(self._dates) >= 2 and self._dates[1] <= self._dates[0]:
 *             self._isRegular[1] = (self._dates[1] == self._dates[0])
 *             self._dates[1] = self._dates[0]             # <<<<<<<<<<<<<<
 *             self._dates = self._dates[1:]
 *             self._isRegular = self._isRegular[1:]
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 246, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_dates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 246, __pyx_L1_error)
    }
    if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_dates, 1, __pyx_t_2, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":247
 *             self._isRegular[1] = (self._dates[1] == self._dates[0])
 *             self._dates[1] = self._dates[0]
 *             self._dates = self._dates[1:]             # <<<<<<<<<<<<<<
 *             self._isRegular = self._isRegular[1:]
 * 
 */
    if (unlikely(__pyx_v_self->_dates == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 247, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyList_GetSlice(__pyx_v_self->_dates, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_dates);
    __Pyx_DECREF(__pyx_v_self->_dates);
    __pyx_v_self->_dates = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":248
 *             self._dates[1] = self._dates[0]
 *             self._dates = self._dates[1:]
 *             self._isRegular = self._isRegular[1:]             # <<<<<<<<<<<<<<
 * 
 *         #require(len(self._dates) >= 1, ValueError, "degenerate single date ({0}) schedule\n"
 */
    if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 248, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyList_GetSlice(__pyx_v_self->_isRegular, 1, PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_isRegular);
    __Pyx_DECREF(__pyx_v_self->_isRegular);
    __pyx_v_self->_isRegular = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "ultron/tradingday/Schedule.pyx":244
 *             self._isRegular.pop()
 * 
 *         if len(self._dates) >= 2 and self._dates[1] <= self._dates[0]:             # <<<<<<<<<<<<<<
 *             self._isRegular[1] = (self._dates[1] == self._dates[0])
 *             self._dates[1] = self._dates[0]
 */
  }

  /* "ultron/tradingday/Schedule.pyx":13
 * cdef class Schedule(object):
 * 
 *     def __init__(self,             # <<<<<<<<<<<<<<
 *                  Date effectiveDate,
 *                  Date terminationDate,
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_nullCalendar);
  __Pyx_XDECREF((PyObject *)__pyx_v_evalDate);
  __Pyx_XDECREF((PyObject *)__pyx_v_seed);
  __Pyx_XDECREF((PyObject *)__pyx_v_temp);
  __Pyx_XDECREF((PyObject *)__pyx_v_exitDate);
  __Pyx_XDECREF((PyObject *)__pyx_v_effectiveDate);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":267
 *         #        self._rule, self._endOfMonth))
 * 
 *     cpdef size_t size(self):             # <<<<<<<<<<<<<<
 *         return len(self._dates)
 * 
 */

static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_3size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static size_t __pyx_f_6ultron_10tradingday_8Schedule_8Schedule_size(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch) {
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("size", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_3size)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyInt_As_size_t(__pyx_t_2); if (unlikely((__pyx_t_5 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 267, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "ultron/tradingday/Schedule.pyx":268
 * 
 *     cpdef size_t size(self):
 *         return len(self._dates)             # <<<<<<<<<<<<<<
 * 
 *     cpdef Calendar calendar(self):
 */
  __pyx_t_1 = __pyx_v_self->_dates;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 268, __pyx_L1_error)
  }
  __pyx_t_6 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 268, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":267
 *         #        self._rule, self._endOfMonth))
 * 
 *     cpdef size_t size(self):             # <<<<<<<<<<<<<<
 *         return len(self._dates)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("ultron.tradingday.Schedule.Schedule.size", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_3size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_2size[] = "Schedule.size(self) -> size_t";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_3size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("size (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_2size(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_2size(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("size", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_size(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":270
 *         return len(self._dates)
 * 
 *     cpdef Calendar calendar(self):             # <<<<<<<<<<<<<<
 *         return self._cal
 * 
 */

static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5calendar(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_calendar(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calendar", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_calendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5calendar)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 270, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_8Calendar_Calendar))))) __PYX_ERR(0, 270, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "ultron/tradingday/Schedule.pyx":271
 * 
 *     cpdef Calendar calendar(self):
 *         return self._cal             # <<<<<<<<<<<<<<
 * 
 *     cpdef Period tenor(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_cal));
  __pyx_r = __pyx_v_self->_cal;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":270
 *         return len(self._dates)
 * 
 *     cpdef Calendar calendar(self):             # <<<<<<<<<<<<<<
 *         return self._cal
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.calendar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5calendar(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_4calendar[] = "Schedule.calendar(self) -> Calendar";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5calendar(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calendar (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4calendar(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4calendar(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calendar", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_calendar(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.calendar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":273
 *         return self._cal
 * 
 *     cpdef Period tenor(self):             # <<<<<<<<<<<<<<
 *         return self._tenor
 * 
 */

static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_7tenor(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_6ultron_10tradingday_6Period_Period *__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_tenor(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_6ultron_10tradingday_6Period_Period *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tenor", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_tenor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_7tenor)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6ultron_10tradingday_6Period_Period))))) __PYX_ERR(0, 273, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "ultron/tradingday/Schedule.pyx":274
 * 
 *     cpdef Period tenor(self):
 *         return self._tenor             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint endOfMonth(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_tenor));
  __pyx_r = __pyx_v_self->_tenor;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":273
 *         return self._cal
 * 
 *     cpdef Period tenor(self):             # <<<<<<<<<<<<<<
 *         return self._tenor
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.tenor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_7tenor(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_6tenor[] = "Schedule.tenor(self) -> Period";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_7tenor(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tenor (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6tenor(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6tenor(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tenor", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_tenor(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.tenor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":276
 *         return self._tenor
 * 
 *     cpdef bint endOfMonth(self):             # <<<<<<<<<<<<<<
 *         return self._endOfMonth
 * 
 */

static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_9endOfMonth(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_6ultron_10tradingday_8Schedule_8Schedule_endOfMonth(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("endOfMonth", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_endOfMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_9endOfMonth)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 276, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "ultron/tradingday/Schedule.pyx":277
 * 
 *     cpdef bint endOfMonth(self):
 *         return self._endOfMonth             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isRegular(self, size_t i):
 */
  __pyx_r = __pyx_v_self->_endOfMonth;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":276
 *         return self._tenor
 * 
 *     cpdef bint endOfMonth(self):             # <<<<<<<<<<<<<<
 *         return self._endOfMonth
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("ultron.tradingday.Schedule.Schedule.endOfMonth", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_9endOfMonth(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_8endOfMonth[] = "Schedule.endOfMonth(self) -> bool";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_9endOfMonth(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("endOfMonth (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_8endOfMonth(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_8endOfMonth(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("endOfMonth", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_endOfMonth(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.endOfMonth", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":279
 *         return self._endOfMonth
 * 
 *     cpdef bint isRegular(self, size_t i):             # <<<<<<<<<<<<<<
 *         return self._isRegular[i-1]
 * 
 */

static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11isRegular(PyObject *__pyx_v_self, PyObject *__pyx_arg_i); /*proto*/
static int __pyx_f_6ultron_10tradingday_8Schedule_8Schedule_isRegular(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, size_t __pyx_v_i, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRegular", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isRegular); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11isRegular)) {
        __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 279, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 279, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "ultron/tradingday/Schedule.pyx":280
 * 
 *     cpdef bint isRegular(self, size_t i):
 *         return self._isRegular[i-1]             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, item):
 */
  if (unlikely(__pyx_v_self->_isRegular == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 280, __pyx_L1_error)
  }
  __pyx_t_7 = (__pyx_v_i - 1);
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->_isRegular, __pyx_t_7, size_t, 0, __Pyx_PyInt_FromSize_t, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":279
 *         return self._endOfMonth
 * 
 *     cpdef bint isRegular(self, size_t i):             # <<<<<<<<<<<<<<
 *         return self._isRegular[i-1]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_WriteUnraisable("ultron.tradingday.Schedule.Schedule.isRegular", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11isRegular(PyObject *__pyx_v_self, PyObject *__pyx_arg_i); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_10isRegular[] = "Schedule.isRegular(self, size_t i) -> bool";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11isRegular(PyObject *__pyx_v_self, PyObject *__pyx_arg_i) {
  size_t __pyx_v_i;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isRegular (wrapper)", 0);
  assert(__pyx_arg_i); {
    __pyx_v_i = __Pyx_PyInt_As_size_t(__pyx_arg_i); if (unlikely((__pyx_v_i == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 279, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.isRegular", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10isRegular(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((size_t)__pyx_v_i));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10isRegular(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, size_t __pyx_v_i) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("isRegular", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_isRegular(__pyx_v_self, __pyx_v_i, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.isRegular", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":282
 *         return self._isRegular[i-1]
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self._dates[item]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_13__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_13__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_12__getitem__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_12__getitem__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "ultron/tradingday/Schedule.pyx":283
 * 
 *     def __getitem__(self, item):
 *         return self._dates[item]             # <<<<<<<<<<<<<<
 * 
 *     def __deepcopy__(self, memo):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->_dates == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 283, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_self->_dates, __pyx_v_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":282
 *         return self._isRegular[i-1]
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self._dates[item]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":285
 *         return self._dates[item]
 * 
 *     def __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return Schedule(self._effectiveDate,
 *                         self._terminationDate,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15__deepcopy__(PyObject *__pyx_v_self, PyObject *__pyx_v_memo); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_14__deepcopy__[] = "Schedule.__deepcopy__(self, memo)";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15__deepcopy__(PyObject *__pyx_v_self, PyObject *__pyx_v_memo) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__deepcopy__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14__deepcopy__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_memo));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14__deepcopy__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_memo) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__deepcopy__", 0);

  /* "ultron/tradingday/Schedule.pyx":286
 * 
 *     def __deepcopy__(self, memo):
 *         return Schedule(self._effectiveDate,             # <<<<<<<<<<<<<<
 *                         self._terminationDate,
 *                         self._tenor,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "ultron/tradingday/Schedule.pyx":290
 *                         self._tenor,
 *                         self._cal,
 *                         self._convention,             # <<<<<<<<<<<<<<
 *                         self._terminationConvention,
 *                         self._rule,
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_convention); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "ultron/tradingday/Schedule.pyx":291
 *                         self._cal,
 *                         self._convention,
 *                         self._terminationConvention,             # <<<<<<<<<<<<<<
 *                         self._rule,
 *                         self._endOfMonth,
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->_terminationConvention); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "ultron/tradingday/Schedule.pyx":292
 *                         self._convention,
 *                         self._terminationConvention,
 *                         self._rule,             # <<<<<<<<<<<<<<
 *                         self._endOfMonth,
 *                         self._firstDate,
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "ultron/tradingday/Schedule.pyx":293
 *                         self._terminationConvention,
 *                         self._rule,
 *                         self._endOfMonth,             # <<<<<<<<<<<<<<
 *                         self._firstDate,
 *                         self._nextToLastDate)
 */
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_self->_endOfMonth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "ultron/tradingday/Schedule.pyx":286
 * 
 *     def __deepcopy__(self, memo):
 *         return Schedule(self._effectiveDate,             # <<<<<<<<<<<<<<
 *                         self._terminationDate,
 *                         self._tenor,
 */
  __pyx_t_5 = PyTuple_New(10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_self->_effectiveDate);
  __Pyx_GIVEREF(__pyx_v_self->_effectiveDate);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_self->_effectiveDate);
  __Pyx_INCREF(__pyx_v_self->_terminationDate);
  __Pyx_GIVEREF(__pyx_v_self->_terminationDate);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self->_terminationDate);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_tenor));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_tenor));
  PyTuple_SET_ITEM(__pyx_t_5, 2, ((PyObject *)__pyx_v_self->_tenor));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_cal));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_cal));
  PyTuple_SET_ITEM(__pyx_t_5, 3, ((PyObject *)__pyx_v_self->_cal));
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 5, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 6, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 7, __pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_firstDate));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_firstDate));
  PyTuple_SET_ITEM(__pyx_t_5, 8, ((PyObject *)__pyx_v_self->_firstDate));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_nextToLastDate));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_nextToLastDate));
  PyTuple_SET_ITEM(__pyx_t_5, 9, ((PyObject *)__pyx_v_self->_nextToLastDate));
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6ultron_10tradingday_8Schedule_Schedule), __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":285
 *         return self._dates[item]
 * 
 *     def __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return Schedule(self._effectiveDate,
 *                         self._terminationDate,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.__deepcopy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":297
 *                         self._nextToLastDate)
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         d = {}
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_17__reduce__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_16__reduce__[] = "Schedule.__reduce__(self)";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_17__reduce__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16__reduce__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16__reduce__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce__", 0);

  /* "ultron/tradingday/Schedule.pyx":298
 * 
 *     def __reduce__(self):
 *         d = {}             # <<<<<<<<<<<<<<
 * 
 *         return Schedule, (self._effectiveDate,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_d = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ultron/tradingday/Schedule.pyx":300
 *         d = {}
 * 
 *         return Schedule, (self._effectiveDate,             # <<<<<<<<<<<<<<
 *                           self._terminationDate,
 *                           self._tenor,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "ultron/tradingday/Schedule.pyx":304
 *                           self._tenor,
 *                           self._cal,
 *                           self._convention,             # <<<<<<<<<<<<<<
 *                           self._terminationConvention,
 *                           self._rule,
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_convention); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "ultron/tradingday/Schedule.pyx":305
 *                           self._cal,
 *                           self._convention,
 *                           self._terminationConvention,             # <<<<<<<<<<<<<<
 *                           self._rule,
 *                           self._endOfMonth,
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->_terminationConvention); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "ultron/tradingday/Schedule.pyx":306
 *                           self._convention,
 *                           self._terminationConvention,
 *                           self._rule,             # <<<<<<<<<<<<<<
 *                           self._endOfMonth,
 *                           self._firstDate,
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "ultron/tradingday/Schedule.pyx":307
 *                           self._terminationConvention,
 *                           self._rule,
 *                           self._endOfMonth,             # <<<<<<<<<<<<<<
 *                           self._firstDate,
 *                           self._nextToLastDate), d
 */
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_self->_endOfMonth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "ultron/tradingday/Schedule.pyx":300
 *         d = {}
 * 
 *         return Schedule, (self._effectiveDate,             # <<<<<<<<<<<<<<
 *                           self._terminationDate,
 *                           self._tenor,
 */
  __pyx_t_5 = PyTuple_New(10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_self->_effectiveDate);
  __Pyx_GIVEREF(__pyx_v_self->_effectiveDate);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_self->_effectiveDate);
  __Pyx_INCREF(__pyx_v_self->_terminationDate);
  __Pyx_GIVEREF(__pyx_v_self->_terminationDate);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self->_terminationDate);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_tenor));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_tenor));
  PyTuple_SET_ITEM(__pyx_t_5, 2, ((PyObject *)__pyx_v_self->_tenor));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_cal));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_cal));
  PyTuple_SET_ITEM(__pyx_t_5, 3, ((PyObject *)__pyx_v_self->_cal));
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 5, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 6, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 7, __pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_firstDate));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_firstDate));
  PyTuple_SET_ITEM(__pyx_t_5, 8, ((PyObject *)__pyx_v_self->_firstDate));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_nextToLastDate));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_nextToLastDate));
  PyTuple_SET_ITEM(__pyx_t_5, 9, ((PyObject *)__pyx_v_self->_nextToLastDate));
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "ultron/tradingday/Schedule.pyx":309
 *                           self._endOfMonth,
 *                           self._firstDate,
 *                           self._nextToLastDate), d             # <<<<<<<<<<<<<<
 * 
 *     def __setstate__(self, state):
 */
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_ptype_6ultron_10tradingday_8Schedule_Schedule));
  __Pyx_GIVEREF(((PyObject *)__pyx_ptype_6ultron_10tradingday_8Schedule_Schedule));
  PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_ptype_6ultron_10tradingday_8Schedule_Schedule));
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
  __Pyx_INCREF(__pyx_v_d);
  __Pyx_GIVEREF(__pyx_v_d);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_d);
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "ultron/tradingday/Schedule.pyx":297
 *                         self._nextToLastDate)
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         d = {}
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":311
 *                           self._nextToLastDate), d
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_19__setstate__(PyObject *__pyx_v_self, PyObject *__pyx_v_state); /*proto*/
static char __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_18__setstate__[] = "Schedule.__setstate__(self, state)";
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_19__setstate__(PyObject *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_18__setstate__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_18__setstate__(CYTHON_UNUSED struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__", 0);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pyx":314
 *         pass
 * 
 *     def __richcmp__(self, Schedule other, int op):             # <<<<<<<<<<<<<<
 *         if op == 2:
 *             return self._effectiveDate == other._effectiveDate \
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_21__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_v_op); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_21__richcmp__(PyObject *__pyx_v_self, PyObject *__pyx_v_other, int __pyx_v_op) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__richcmp__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_6ultron_10tradingday_8Schedule_Schedule, 1, "other", 0))) __PYX_ERR(0, 314, __pyx_L1_error)
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_20__richcmp__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_other), ((int)__pyx_v_op));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_20__richcmp__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_other, int __pyx_v_op) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__richcmp__", 0);

  /* "ultron/tradingday/Schedule.pyx":315
 * 
 *     def __richcmp__(self, Schedule other, int op):
 *         if op == 2:             # <<<<<<<<<<<<<<
 *             return self._effectiveDate == other._effectiveDate \
 *                    and self._terminationDate == other._terminationDate \
 */
  __pyx_t_1 = ((__pyx_v_op == 2) != 0);
  if (__pyx_t_1) {

    /* "ultron/tradingday/Schedule.pyx":316
 *     def __richcmp__(self, Schedule other, int op):
 *         if op == 2:
 *             return self._effectiveDate == other._effectiveDate \             # <<<<<<<<<<<<<<
 *                    and self._terminationDate == other._terminationDate \
 *                    and self._tenor == other._tenor \
 */
    __Pyx_XDECREF(__pyx_r);

    /* "ultron/tradingday/Schedule.pyx":317
 *         if op == 2:
 *             return self._effectiveDate == other._effectiveDate \
 *                    and self._terminationDate == other._terminationDate \             # <<<<<<<<<<<<<<
 *                    and self._tenor == other._tenor \
 *                    and self._cal == other._cal \
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_self->_effectiveDate, __pyx_v_other->_effectiveDate, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 316, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 316, __pyx_L1_error)
    if (__pyx_t_1) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":318
 *             return self._effectiveDate == other._effectiveDate \
 *                    and self._terminationDate == other._terminationDate \
 *                    and self._tenor == other._tenor \             # <<<<<<<<<<<<<<
 *                    and self._cal == other._cal \
 *                    and self._convention == other._convention \
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_self->_terminationDate, __pyx_v_other->_terminationDate, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 317, __pyx_L1_error)
    if (__pyx_t_1) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":319
 *                    and self._terminationDate == other._terminationDate \
 *                    and self._tenor == other._tenor \
 *                    and self._cal == other._cal \             # <<<<<<<<<<<<<<
 *                    and self._convention == other._convention \
 *                    and self._terminationConvention == other._terminationConvention \
 */
    __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_self->_tenor), ((PyObject *)__pyx_v_other->_tenor), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 318, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 318, __pyx_L1_error)
    if (__pyx_t_1) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":320
 *                    and self._tenor == other._tenor \
 *                    and self._cal == other._cal \
 *                    and self._convention == other._convention \             # <<<<<<<<<<<<<<
 *                    and self._terminationConvention == other._terminationConvention \
 *                    and self._rule == other._rule \
 */
    __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_self->_cal), ((PyObject *)__pyx_v_other->_cal), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 319, __pyx_L1_error)
    if (__pyx_t_1) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":321
 *                    and self._cal == other._cal \
 *                    and self._convention == other._convention \
 *                    and self._terminationConvention == other._terminationConvention \             # <<<<<<<<<<<<<<
 *                    and self._rule == other._rule \
 *                    and self._endOfMonth == other._endOfMonth \
 */
    __pyx_t_1 = (__pyx_v_self->_convention == __pyx_v_other->_convention);
    if (__pyx_t_1) {
    } else {

      /* "ultron/tradingday/Schedule.pyx":320
 *                    and self._tenor == other._tenor \
 *                    and self._cal == other._cal \
 *                    and self._convention == other._convention \             # <<<<<<<<<<<<<<
 *                    and self._terminationConvention == other._terminationConvention \
 *                    and self._rule == other._rule \
 */
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":321
 *                    and self._cal == other._cal \
 *                    and self._convention == other._convention \
 *                    and self._terminationConvention == other._terminationConvention \             # <<<<<<<<<<<<<<
 *                    and self._rule == other._rule \
 *                    and self._endOfMonth == other._endOfMonth \
 */
    __pyx_t_1 = (__pyx_v_self->_terminationConvention == __pyx_v_other->_terminationConvention);
    if (__pyx_t_1) {
    } else {
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":322
 *                    and self._convention == other._convention \
 *                    and self._terminationConvention == other._terminationConvention \
 *                    and self._rule == other._rule \             # <<<<<<<<<<<<<<
 *                    and self._endOfMonth == other._endOfMonth \
 *                    and self._firstDate == other._firstDate \
 */
    __pyx_t_1 = (__pyx_v_self->_rule == __pyx_v_other->_rule);
    if (__pyx_t_1) {
    } else {
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 322, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":323
 *                    and self._terminationConvention == other._terminationConvention \
 *                    and self._rule == other._rule \
 *                    and self._endOfMonth == other._endOfMonth \             # <<<<<<<<<<<<<<
 *                    and self._firstDate == other._firstDate \
 *                    and self._nextToLastDate == other._nextToLastDate
 */
    __pyx_t_1 = (__pyx_v_self->_endOfMonth == __pyx_v_other->_endOfMonth);
    if (__pyx_t_1) {
    } else {
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 323, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":324
 *                    and self._rule == other._rule \
 *                    and self._endOfMonth == other._endOfMonth \
 *                    and self._firstDate == other._firstDate \             # <<<<<<<<<<<<<<
 *                    and self._nextToLastDate == other._nextToLastDate
 */
    __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_self->_firstDate), ((PyObject *)__pyx_v_other->_firstDate), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 324, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 324, __pyx_L1_error)
    if (__pyx_t_1) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L4_bool_binop_done;
    }

    /* "ultron/tradingday/Schedule.pyx":325
 *                    and self._endOfMonth == other._endOfMonth \
 *                    and self._firstDate == other._firstDate \
 *                    and self._nextToLastDate == other._nextToLastDate             # <<<<<<<<<<<<<<
 */
    __pyx_t_3 = PyObject_RichCompare(((PyObject *)__pyx_v_self->_nextToLastDate), ((PyObject *)__pyx_v_other->_nextToLastDate), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 325, __pyx_L1_error)
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_L4_bool_binop_done:;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "ultron/tradingday/Schedule.pyx":315
 * 
 *     def __richcmp__(self, Schedule other, int op):
 *         if op == 2:             # <<<<<<<<<<<<<<
 *             return self._effectiveDate == other._effectiveDate \
 *                    and self._terminationDate == other._terminationDate \
 */
  }

  /* "ultron/tradingday/Schedule.pyx":314
 *         pass
 * 
 *     def __richcmp__(self, Schedule other, int op):             # <<<<<<<<<<<<<<
 *         if op == 2:
 *             return self._effectiveDate == other._effectiveDate \
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule.__richcmp__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":10
 * cdef class Schedule(object):
 * 
 *     cdef public _effectiveDate             # <<<<<<<<<<<<<<
 *     cdef public _terminationDate
 *     cdef public Period _tenor
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_effectiveDate);
  __pyx_r = __pyx_v_self->_effectiveDate;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_effectiveDate);
  __Pyx_DECREF(__pyx_v_self->_effectiveDate);
  __pyx_v_self->_effectiveDate = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_effectiveDate);
  __Pyx_DECREF(__pyx_v_self->_effectiveDate);
  __pyx_v_self->_effectiveDate = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":11
 * 
 *     cdef public _effectiveDate
 *     cdef public _terminationDate             # <<<<<<<<<<<<<<
 *     cdef public Period _tenor
 *     cdef public Calendar _cal
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_terminationDate);
  __pyx_r = __pyx_v_self->_terminationDate;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->_terminationDate);
  __Pyx_DECREF(__pyx_v_self->_terminationDate);
  __pyx_v_self->_terminationDate = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_terminationDate);
  __Pyx_DECREF(__pyx_v_self->_terminationDate);
  __pyx_v_self->_terminationDate = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":12
 *     cdef public _effectiveDate
 *     cdef public _terminationDate
 *     cdef public Period _tenor             # <<<<<<<<<<<<<<
 *     cdef public Calendar _cal
 *     cdef public int _convention
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_tenor));
  __pyx_r = ((PyObject *)__pyx_v_self->_tenor);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6ultron_10tradingday_6Period_Period))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_tenor);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_tenor));
  __pyx_v_self->_tenor = ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._tenor.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_tenor);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_tenor));
  __pyx_v_self->_tenor = ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":13
 *     cdef public _terminationDate
 *     cdef public Period _tenor
 *     cdef public Calendar _cal             # <<<<<<<<<<<<<<
 *     cdef public int _convention
 *     cdef public int _terminationConvention
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_cal));
  __pyx_r = ((PyObject *)__pyx_v_self->_cal);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6ultron_10tradingday_8Calendar_Calendar))))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_cal);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_cal));
  __pyx_v_self->_cal = ((struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._cal.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_4_cal_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_cal);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_cal));
  __pyx_v_self->_cal = ((struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":14
 *     cdef public Period _tenor
 *     cdef public Calendar _cal
 *     cdef public int _convention             # <<<<<<<<<<<<<<
 *     cdef public int _terminationConvention
 *     cdef public int _rule
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_convention_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_convention_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_convention___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_convention___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_convention); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._convention.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_convention_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_convention_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_convention_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_convention_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 14, __pyx_L1_error)
  __pyx_v_self->_convention = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._convention.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":15
 *     cdef public Calendar _cal
 *     cdef public int _convention
 *     cdef public int _terminationConvention             # <<<<<<<<<<<<<<
 *     cdef public int _rule
 *     cdef public list _dates
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_terminationConvention); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._terminationConvention.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 15, __pyx_L1_error)
  __pyx_v_self->_terminationConvention = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._terminationConvention.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":16
 *     cdef public int _convention
 *     cdef public int _terminationConvention
 *     cdef public int _rule             # <<<<<<<<<<<<<<
 *     cdef public list _dates
 *     cdef public list _isRegular
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5_rule_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5_rule_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_5_rule___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_5_rule___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_rule); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._rule.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5_rule_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5_rule_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_5_rule_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_5_rule_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L1_error)
  __pyx_v_self->_rule = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._rule.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":17
 *     cdef public int _terminationConvention
 *     cdef public int _rule
 *     cdef public list _dates             # <<<<<<<<<<<<<<
 *     cdef public list _isRegular
 *     cdef public bint _endOfMonth
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_dates);
  __pyx_r = __pyx_v_self->_dates;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_dates);
  __Pyx_DECREF(__pyx_v_self->_dates);
  __pyx_v_self->_dates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._dates.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_6_dates_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_dates);
  __Pyx_DECREF(__pyx_v_self->_dates);
  __pyx_v_self->_dates = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":18
 *     cdef public int _rule
 *     cdef public list _dates
 *     cdef public list _isRegular             # <<<<<<<<<<<<<<
 *     cdef public bint _endOfMonth
 *     cdef public Date _firstDate
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_isRegular);
  __pyx_r = __pyx_v_self->_isRegular;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(1, 18, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_isRegular);
  __Pyx_DECREF(__pyx_v_self->_isRegular);
  __pyx_v_self->_isRegular = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._isRegular.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_isRegular);
  __Pyx_DECREF(__pyx_v_self->_isRegular);
  __pyx_v_self->_isRegular = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":19
 *     cdef public list _dates
 *     cdef public list _isRegular
 *     cdef public bint _endOfMonth             # <<<<<<<<<<<<<<
 *     cdef public Date _firstDate
 *     cdef public Date _nextToLastDate
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_endOfMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._endOfMonth.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 19, __pyx_L1_error)
  __pyx_v_self->_endOfMonth = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._endOfMonth.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":20
 *     cdef public list _isRegular
 *     cdef public bint _endOfMonth
 *     cdef public Date _firstDate             # <<<<<<<<<<<<<<
 *     cdef public Date _nextToLastDate
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_firstDate));
  __pyx_r = ((PyObject *)__pyx_v_self->_firstDate);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(1, 20, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_firstDate);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_firstDate));
  __pyx_v_self->_firstDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._firstDate.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_firstDate);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_firstDate));
  __pyx_v_self->_firstDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ultron/tradingday/Schedule.pxd":21
 *     cdef public bint _endOfMonth
 *     cdef public Date _firstDate
 *     cdef public Date _nextToLastDate             # <<<<<<<<<<<<<<
 * 
 *     cpdef size_t size(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate___get__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate___get__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_nextToLastDate));
  __pyx_r = ((PyObject *)__pyx_v_self->_nextToLastDate);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_2__set__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_2__set__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6ultron_10tradingday_4Date_Date))))) __PYX_ERR(1, 21, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_nextToLastDate);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_nextToLastDate));
  __pyx_v_self->_nextToLastDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("ultron.tradingday.Schedule.Schedule._nextToLastDate.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_4__del__(((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_4__del__(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_nextToLastDate);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_nextToLastDate));
  __pyx_v_self->_nextToLastDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_6ultron_10tradingday_8Schedule_Schedule __pyx_vtable_6ultron_10tradingday_8Schedule_Schedule;

static PyObject *__pyx_tp_new_6ultron_10tradingday_8Schedule_Schedule(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)o);
  p->__pyx_vtab = __pyx_vtabptr_6ultron_10tradingday_8Schedule_Schedule;
  p->_effectiveDate = Py_None; Py_INCREF(Py_None);
  p->_terminationDate = Py_None; Py_INCREF(Py_None);
  p->_tenor = ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)Py_None); Py_INCREF(Py_None);
  p->_cal = ((struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *)Py_None); Py_INCREF(Py_None);
  p->_dates = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_isRegular = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_firstDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None); Py_INCREF(Py_None);
  p->_nextToLastDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6ultron_10tradingday_8Schedule_Schedule(PyObject *o) {
  struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *p = (struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_effectiveDate);
  Py_CLEAR(p->_terminationDate);
  Py_CLEAR(p->_tenor);
  Py_CLEAR(p->_cal);
  Py_CLEAR(p->_dates);
  Py_CLEAR(p->_isRegular);
  Py_CLEAR(p->_firstDate);
  Py_CLEAR(p->_nextToLastDate);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6ultron_10tradingday_8Schedule_Schedule(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *p = (struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)o;
  if (p->_effectiveDate) {
    e = (*v)(p->_effectiveDate, a); if (e) return e;
  }
  if (p->_terminationDate) {
    e = (*v)(p->_terminationDate, a); if (e) return e;
  }
  if (p->_tenor) {
    e = (*v)(((PyObject *)p->_tenor), a); if (e) return e;
  }
  if (p->_cal) {
    e = (*v)(((PyObject *)p->_cal), a); if (e) return e;
  }
  if (p->_dates) {
    e = (*v)(p->_dates, a); if (e) return e;
  }
  if (p->_isRegular) {
    e = (*v)(p->_isRegular, a); if (e) return e;
  }
  if (p->_firstDate) {
    e = (*v)(((PyObject *)p->_firstDate), a); if (e) return e;
  }
  if (p->_nextToLastDate) {
    e = (*v)(((PyObject *)p->_nextToLastDate), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6ultron_10tradingday_8Schedule_Schedule(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *p = (struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *)o;
  tmp = ((PyObject*)p->_effectiveDate);
  p->_effectiveDate = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_terminationDate);
  p->_terminationDate = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_tenor);
  p->_tenor = ((struct __pyx_obj_6ultron_10tradingday_6Period_Period *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_cal);
  p->_cal = ((struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_dates);
  p->_dates = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_isRegular);
  p->_isRegular = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_firstDate);
  p->_firstDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_nextToLastDate);
  p->_nextToLastDate = ((struct __pyx_obj_6ultron_10tradingday_4Date_Date *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_6ultron_10tradingday_8Schedule_Schedule(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__effectiveDate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__effectiveDate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_14_effectiveDate_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__terminationDate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__terminationDate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_16_terminationDate_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__tenor(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__tenor(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_tenor_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__cal(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__cal(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_4_cal_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__convention(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_convention_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__convention(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_convention_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__terminationConvention(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__terminationConvention(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_22_terminationConvention_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__rule(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5_rule_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__rule(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5_rule_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__dates(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__dates(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_6_dates_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__isRegular(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__isRegular(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_isRegular_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__endOfMonth(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__endOfMonth(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11_endOfMonth_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__firstDate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__firstDate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_10_firstDate_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__nextToLastDate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_1__get__(o);
}

static int __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__nextToLastDate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_3__set__(o, v);
  }
  else {
    return __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15_nextToLastDate_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6ultron_10tradingday_8Schedule_Schedule[] = {
  {"size", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_3size, METH_NOARGS, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_2size},
  {"calendar", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_5calendar, METH_NOARGS, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_4calendar},
  {"tenor", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_7tenor, METH_NOARGS, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_6tenor},
  {"endOfMonth", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_9endOfMonth, METH_NOARGS, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_8endOfMonth},
  {"isRegular", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_11isRegular, METH_O, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_10isRegular},
  {"__deepcopy__", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_15__deepcopy__, METH_O, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_14__deepcopy__},
  {"__reduce__", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_17__reduce__, METH_NOARGS, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_16__reduce__},
  {"__setstate__", (PyCFunction)__pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_19__setstate__, METH_O, __pyx_doc_6ultron_10tradingday_8Schedule_8Schedule_18__setstate__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6ultron_10tradingday_8Schedule_Schedule[] = {
  {(char *)"_effectiveDate", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__effectiveDate, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__effectiveDate, (char *)"_effectiveDate: object", 0},
  {(char *)"_terminationDate", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__terminationDate, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__terminationDate, (char *)"_terminationDate: object", 0},
  {(char *)"_tenor", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__tenor, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__tenor, (char *)"_tenor: ultron.tradingday.Period.Period", 0},
  {(char *)"_cal", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__cal, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__cal, (char *)"_cal: ultron.tradingday.Calendar.Calendar", 0},
  {(char *)"_convention", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__convention, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__convention, (char *)"_convention: 'int'", 0},
  {(char *)"_terminationConvention", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__terminationConvention, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__terminationConvention, (char *)"_terminationConvention: 'int'", 0},
  {(char *)"_rule", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__rule, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__rule, (char *)"_rule: 'int'", 0},
  {(char *)"_dates", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__dates, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__dates, (char *)"_dates: list", 0},
  {(char *)"_isRegular", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__isRegular, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__isRegular, (char *)"_isRegular: list", 0},
  {(char *)"_endOfMonth", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__endOfMonth, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__endOfMonth, (char *)"_endOfMonth: 'bool'", 0},
  {(char *)"_firstDate", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__firstDate, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__firstDate, (char *)"_firstDate: ultron.tradingday.Date.Date", 0},
  {(char *)"_nextToLastDate", __pyx_getprop_6ultron_10tradingday_8Schedule_8Schedule__nextToLastDate, __pyx_setprop_6ultron_10tradingday_8Schedule_8Schedule__nextToLastDate, (char *)"_nextToLastDate: ultron.tradingday.Date.Date", 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_Schedule = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_6ultron_10tradingday_8Schedule_Schedule, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Schedule = {
  0, /*mp_length*/
  __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_13__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6ultron_10tradingday_8Schedule_Schedule = {
  PyVarObject_HEAD_INIT(0, 0)
  "ultron.tradingday.Schedule.Schedule", /*tp_name*/
  sizeof(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6ultron_10tradingday_8Schedule_Schedule, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Schedule, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Schedule, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Schedule(Date effectiveDate, Date terminationDate, Period tenor, Calendar calendar, int convention=BizDayConventions.Following, int terminationConvention=BizDayConventions.Following, int dateGenerationRule=DateGeneration.Forward, bool endOfMonth=False, Date firstDate=None, Date nextToLastDate=None)", /*tp_doc*/
  __pyx_tp_traverse_6ultron_10tradingday_8Schedule_Schedule, /*tp_traverse*/
  __pyx_tp_clear_6ultron_10tradingday_8Schedule_Schedule, /*tp_clear*/
  __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_21__richcmp__, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6ultron_10tradingday_8Schedule_Schedule, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6ultron_10tradingday_8Schedule_Schedule, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_6ultron_10tradingday_8Schedule_8Schedule_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6ultron_10tradingday_8Schedule_Schedule, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_Schedule(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_Schedule},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "Schedule",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_1M, __pyx_k_1M, sizeof(__pyx_k_1M), 0, 0, 1, 0},
  {&__pyx_n_s_Null, __pyx_k_Null, sizeof(__pyx_k_Null), 0, 0, 1, 1},
  {&__pyx_n_s_Schedule, __pyx_k_Schedule, sizeof(__pyx_k_Schedule), 0, 0, 1, 1},
  {&__pyx_n_s_Settings, __pyx_k_Settings, sizeof(__pyx_k_Settings), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s_calendar, __pyx_k_calendar, sizeof(__pyx_k_calendar), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_convention, __pyx_k_convention, sizeof(__pyx_k_convention), 0, 0, 1, 1},
  {&__pyx_n_s_dateGenerationRule, __pyx_k_dateGenerationRule, sizeof(__pyx_k_dateGenerationRule), 0, 0, 1, 1},
  {&__pyx_n_s_effectiveDate, __pyx_k_effectiveDate, sizeof(__pyx_k_effectiveDate), 0, 0, 1, 1},
  {&__pyx_n_s_endOfMonth, __pyx_k_endOfMonth, sizeof(__pyx_k_endOfMonth), 0, 0, 1, 1},
  {&__pyx_n_s_evaluationDate, __pyx_k_evaluationDate, sizeof(__pyx_k_evaluationDate), 0, 0, 1, 1},
  {&__pyx_n_s_firstDate, __pyx_k_firstDate, sizeof(__pyx_k_firstDate), 0, 0, 1, 1},
  {&__pyx_kp_s_first_date_incompatible_with_0_d, __pyx_k_first_date_incompatible_with_0_d, sizeof(__pyx_k_first_date_incompatible_with_0_d), 0, 0, 1, 0},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_isRegular, __pyx_k_isRegular, sizeof(__pyx_k_isRegular), 0, 0, 1, 1},
  {&__pyx_n_s_length, __pyx_k_length, sizeof(__pyx_k_length), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_nextToLastDate, __pyx_k_nextToLastDate, sizeof(__pyx_k_nextToLastDate), 0, 0, 1, 1},
  {&__pyx_kp_s_next_to_last_date_incompatible_w, __pyx_k_next_to_last_date_incompatible_w, sizeof(__pyx_k_next_to_last_date_incompatible_w), 0, 0, 1, 0},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
  {&__pyx_n_s_tenor, __pyx_k_tenor, sizeof(__pyx_k_tenor), 0, 0, 1, 1},
  {&__pyx_n_s_terminationConvention, __pyx_k_terminationConvention, sizeof(__pyx_k_terminationConvention), 0, 0, 1, 1},
  {&__pyx_n_s_terminationDate, __pyx_k_terminationDate, sizeof(__pyx_k_terminationDate), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_ultron_tradingday_Env, __pyx_k_ultron_tradingday_Env, sizeof(__pyx_k_ultron_tradingday_Env), 0, 0, 1, 1},
  {&__pyx_n_s_units, __pyx_k_units, sizeof(__pyx_k_units), 0, 0, 1, 1},
  {&__pyx_kp_s_unknown_rule_0_d, __pyx_k_unknown_rule_0_d, sizeof(__pyx_k_unknown_rule_0_d), 0, 0, 1, 0},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 95, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 210, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "ultron/tradingday/Schedule.pyx":46
 *         self._isRegular = []
 * 
 *         if tenor < Period("1M"):             # <<<<<<<<<<<<<<
 *             self._endOfMonth = False
 *         else:
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_s_1M); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "ultron/tradingday/Schedule.pyx":113
 * 
 *         # calendar needed for endOfMonth adjustment
 *         nullCalendar = Calendar("Null")             # <<<<<<<<<<<<<<
 *         periods = 1
 * 
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_n_s_Null); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_366 = PyInt_FromLong(366); if (unlikely(!__pyx_int_366)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_6ultron_10tradingday_8Schedule_Schedule = &__pyx_vtable_6ultron_10tradingday_8Schedule_Schedule;
  __pyx_vtable_6ultron_10tradingday_8Schedule_Schedule.size = (size_t (*)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch))__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_size;
  __pyx_vtable_6ultron_10tradingday_8Schedule_Schedule.isRegular = (int (*)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, size_t, int __pyx_skip_dispatch))__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_isRegular;
  __pyx_vtable_6ultron_10tradingday_8Schedule_Schedule.calendar = (struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar *(*)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch))__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_calendar;
  __pyx_vtable_6ultron_10tradingday_8Schedule_Schedule.tenor = (struct __pyx_obj_6ultron_10tradingday_6Period_Period *(*)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch))__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_tenor;
  __pyx_vtable_6ultron_10tradingday_8Schedule_Schedule.endOfMonth = (int (*)(struct __pyx_obj_6ultron_10tradingday_8Schedule_Schedule *, int __pyx_skip_dispatch))__pyx_f_6ultron_10tradingday_8Schedule_8Schedule_endOfMonth;
  if (PyType_Ready(&__pyx_type_6ultron_10tradingday_8Schedule_Schedule) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_6ultron_10tradingday_8Schedule_Schedule.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6ultron_10tradingday_8Schedule_Schedule.tp_dictoffset && __pyx_type_6ultron_10tradingday_8Schedule_Schedule.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6ultron_10tradingday_8Schedule_Schedule.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6ultron_10tradingday_8Schedule_Schedule.tp_dict, __pyx_vtabptr_6ultron_10tradingday_8Schedule_Schedule) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Schedule, (PyObject *)&__pyx_type_6ultron_10tradingday_8Schedule_Schedule) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  __pyx_ptype_6ultron_10tradingday_8Schedule_Schedule = &__pyx_type_6ultron_10tradingday_8Schedule_Schedule;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("ultron.tradingday.Date"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6ultron_10tradingday_4Date_Date = __Pyx_ImportType(__pyx_t_1, "ultron.tradingday.Date", "Date", sizeof(struct __pyx_obj_6ultron_10tradingday_4Date_Date), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ultron_10tradingday_4Date_Date) __PYX_ERR(2, 3, __pyx_L1_error)
  __pyx_vtabptr_6ultron_10tradingday_4Date_Date = (struct __pyx_vtabstruct_6ultron_10tradingday_4Date_Date*)__Pyx_GetVtable(__pyx_ptype_6ultron_10tradingday_4Date_Date->tp_dict); if (unlikely(!__pyx_vtabptr_6ultron_10tradingday_4Date_Date)) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ultron.tradingday.Period"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6ultron_10tradingday_6Period_Period = __Pyx_ImportType(__pyx_t_1, "ultron.tradingday.Period", "Period", sizeof(struct __pyx_obj_6ultron_10tradingday_6Period_Period), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ultron_10tradingday_6Period_Period) __PYX_ERR(3, 3, __pyx_L1_error)
  __pyx_vtabptr_6ultron_10tradingday_6Period_Period = (struct __pyx_vtabstruct_6ultron_10tradingday_6Period_Period*)__Pyx_GetVtable(__pyx_ptype_6ultron_10tradingday_6Period_Period->tp_dict); if (unlikely(!__pyx_vtabptr_6ultron_10tradingday_6Period_Period)) __PYX_ERR(3, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("ultron.tradingday.Calendar"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6ultron_10tradingday_8Calendar_CalendarImpl = __Pyx_ImportType(__pyx_t_1, "ultron.tradingday.Calendar", "CalendarImpl", sizeof(struct __pyx_obj_6ultron_10tradingday_8Calendar_CalendarImpl), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ultron_10tradingday_8Calendar_CalendarImpl) __PYX_ERR(4, 7, __pyx_L1_error)
  __pyx_vtabptr_6ultron_10tradingday_8Calendar_CalendarImpl = (struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_CalendarImpl*)__Pyx_GetVtable(__pyx_ptype_6ultron_10tradingday_8Calendar_CalendarImpl->tp_dict); if (unlikely(!__pyx_vtabptr_6ultron_10tradingday_8Calendar_CalendarImpl)) __PYX_ERR(4, 7, __pyx_L1_error)
  __pyx_ptype_6ultron_10tradingday_8Calendar_Calendar = __Pyx_ImportType(__pyx_t_1, "ultron.tradingday.Calendar", "Calendar", sizeof(struct __pyx_obj_6ultron_10tradingday_8Calendar_Calendar), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_6ultron_10tradingday_8Calendar_Calendar) __PYX_ERR(4, 13, __pyx_L1_error)
  __pyx_vtabptr_6ultron_10tradingday_8Calendar_Calendar = (struct __pyx_vtabstruct_6ultron_10tradingday_8Calendar_Calendar*)__Pyx_GetVtable(__pyx_ptype_6ultron_10tradingday_8Calendar_Calendar->tp_dict); if (unlikely(!__pyx_vtabptr_6ultron_10tradingday_8Calendar_Calendar)) __PYX_ERR(4, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initSchedule(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initSchedule(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_Schedule(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_Schedule(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_Schedule(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'Schedule' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_Schedule(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("Schedule", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_ultron__tradingday__Schedule) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "ultron.tradingday.Schedule")) {
      if (unlikely(PyDict_SetItemString(modules, "ultron.tradingday.Schedule", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "ultron/tradingday/Schedule.pyx":9
 * from ultron.tradingday.Period cimport Period
 * from ultron.tradingday.Calendar cimport Calendar
 * from ultron.tradingday.Env import Settings             # <<<<<<<<<<<<<<
 * 
 * cdef class Schedule(object):
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_Settings);
  __Pyx_GIVEREF(__pyx_n_s_Settings);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_Settings);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_ultron_tradingday_Env, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Settings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Settings, __pyx_t_1) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ultron/tradingday/Schedule.pyx":18
 *                  Period tenor,
 *                  Calendar calendar,
 *                  int convention=BizDayConventions.Following,             # <<<<<<<<<<<<<<
 *                  int terminationConvention=BizDayConventions.Following,
 *                  int dateGenerationRule=DateGeneration.Forward,
 */
  __pyx_k_ = Following;

  /* "ultron/tradingday/Schedule.pyx":19
 *                  Calendar calendar,
 *                  int convention=BizDayConventions.Following,
 *                  int terminationConvention=BizDayConventions.Following,             # <<<<<<<<<<<<<<
 *                  int dateGenerationRule=DateGeneration.Forward,
 *                  bint endOfMonth=False,
 */
  __pyx_k__2 = Following;

  /* "ultron/tradingday/Schedule.pyx":20
 *                  int convention=BizDayConventions.Following,
 *                  int terminationConvention=BizDayConventions.Following,
 *                  int dateGenerationRule=DateGeneration.Forward,             # <<<<<<<<<<<<<<
 *                  bint endOfMonth=False,
 *                  Date firstDate=None,
 */
  __pyx_k__3 = Forward;

  /* "ultron/tradingday/Schedule.pyx":1
 * # -*- coding: utf-8 -*-             # <<<<<<<<<<<<<<
 * 
 * from ultron.tradingday.Enums._BizDayConventions cimport BizDayConventions
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init ultron.tradingday.Schedule", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init ultron.tradingday.Schedule");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* None */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* pop */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (Py_TYPE(L) == &PySet_Type) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_n_s_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject** CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyList_New(0);
    dest = PyList_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyListObject*)src)->ob_item + start,
        ((PyListObject*)dest)->ob_item,
        length);
    return dest;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyTuple_New(0);
    dest = PyTuple_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyTupleObject*)src)->ob_item + start,
        ((PyTupleObject*)dest)->ob_item,
        length);
    return dest;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__TimeUnits(enum TimeUnits value) {
    const enum TimeUnits neg_one = (enum TimeUnits) ((enum TimeUnits) 0 - (enum TimeUnits) 1), const_zero = (enum TimeUnits) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum TimeUnits) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum TimeUnits) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum TimeUnits) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum TimeUnits) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum TimeUnits) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum TimeUnits),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
    const size_t neg_one = (size_t) ((size_t) 0 - (size_t) 1), const_zero = (size_t) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(size_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(size_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 2 * PyLong_SHIFT) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 3 * PyLong_SHIFT) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 4 * PyLong_SHIFT) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(size_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(size_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(size_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(size_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
